@@ -22,9 +22,9 @@
 #include <gmodule.h>
 #include <glib.h>
 #include <string.h>
-#include <pk-common.h>
+#include <packagekit-glib/packagekit.h>
+
 #include <pk-backend.h>
-#include <pk-package-ids.h>
 
 /* static bodges */
 static guint _progress_percentage = 0;
@@ -32,7 +32,6 @@ static gulong _signal_timeout = 0;
 static gchar **_package_ids;
 static const gchar *_search;
 static guint _package_current = 0;
-static gboolean _has_service_pack = FALSE;
 static gboolean _repo_enabled_local = FALSE;
 static gboolean _repo_enabled_fedora = TRUE;
 static gboolean _repo_enabled_devel = TRUE;
@@ -186,9 +185,22 @@ backend_get_distro_upgrades (PkBackend *backend)
 static void
 backend_get_files (PkBackend *backend, gchar **package_ids)
 {
+	guint i;
+	guint len;
+	const gchar *package_id;
+
 	pk_backend_set_status (backend, PK_STATUS_ENUM_QUERY);
-	pk_backend_files (backend, "gnome-power-manager;2.6.19;i386;fedora",
-			  "/usr/share/man/man1;/usr/share/man/man1/gnome-power-manager.1.gz");
+
+	len = g_strv_length (package_ids);
+	for (i=0; i<len; i++) {
+		package_id = package_ids[i];
+		if (egg_strequal (package_id, "powertop;1.8-1.fc8;i386;fedora"))
+			pk_backend_files (backend, package_id, "/usr/share/man/man1/boo;/usr/bin/xchat-gnome");
+		else if (egg_strequal (package_id, "kernel;2.6.23-0.115.rc3.git1.fc8;i386;installed"))
+			pk_backend_files (backend, package_id, "/usr/share/man/man1;/usr/share/man/man1/gnome-power-manager.1.gz");
+		else if (egg_strequal (package_id, "gtkhtml2;2.19.1-4.fc8;i386;fedora"))
+			pk_backend_files (backend, package_id, "/usr/share/man/man1;/usr/bin/ck-xinit-session");
+	}
 	pk_backend_finished (backend);
 }
 
@@ -277,6 +289,11 @@ backend_get_updates_timeout (gpointer data)
 {
 	PkBackend *backend = (PkBackend *) data;
 
+	if (!_updated_powertop && !_updated_kernel && !_updated_gtkhtml) {
+		pk_backend_package (backend, PK_INFO_ENUM_BLOCKED,
+				    "vino;2.24.2.fc9;i386;fedora",
+				    "Remote desktop server for the desktop");
+	}
 	if (!_updated_powertop) {
 		pk_backend_package (backend, PK_INFO_ENUM_NORMAL,
 				    "powertop;1.8-1.fc8;i386;fedora",
@@ -494,14 +511,29 @@ backend_refresh_cache (PkBackend *backend, gboolean force)
 static void
 backend_resolve (PkBackend *backend, PkBitfield filters, gchar **packages)
 {
+	guint i;
+	guint len;
+
 	pk_backend_set_status (backend, PK_STATUS_ENUM_QUERY);
-	if (egg_strequal (packages[0], "vips-doc")) {
-		pk_backend_package (backend, PK_INFO_ENUM_AVAILABLE,
-				    "vips-doc;7.12.4-2.fc8;noarch;linva",
-				    "The vips documentation package.");
-	} else if (egg_strequal (packages[0], "glib2")) {
-		pk_backend_package (backend, PK_INFO_ENUM_INSTALLED,
-				    "glib2;2.14.0;i386;fedora", "The GLib library");
+
+	/* each one has a different detail for testing */
+	len = g_strv_length (packages);
+	for (i=0; i<len; i++) {
+		if (egg_strequal (packages[i], "vips-doc"))
+			pk_backend_package (backend, PK_INFO_ENUM_AVAILABLE,
+					    "vips-doc;7.12.4-2.fc8;noarch;linva", "The vips documentation package.");
+		else if (egg_strequal (packages[i], "glib2"))
+			pk_backend_package (backend, PK_INFO_ENUM_INSTALLED,
+					    "glib2;2.14.0;i386;fedora", "The GLib library");
+		else if (egg_strequal (packages[i], "powertop"))
+			pk_backend_package (backend, PK_INFO_ENUM_UPDATING,
+					    "powertop;1.8-1.fc8;i386;fedora", "Power consumption monitor");
+		else if (egg_strequal (packages[i], "kernel"))
+			pk_backend_package (backend, PK_INFO_ENUM_UPDATING,
+					    "kernel;2.6.23-0.115.rc3.git1.fc8;i386;installed", "The Linux kernel (the core of the Linux operating system)");
+		else if (egg_strequal (packages[i], "gtkhtml2"))
+			pk_backend_package (backend, PK_INFO_ENUM_UPDATING,
+					    "gtkhtml2;2.19.1-4.fc8;i386;fedora", "An HTML widget for GTK+ 2.0");
 	}
 	pk_backend_finished (backend);
 }
@@ -765,10 +797,6 @@ static void
 backend_get_repo_list (PkBackend *backend, PkBitfield filters)
 {
 	pk_backend_set_status (backend, PK_STATUS_ENUM_QUERY);
-	if (_has_service_pack) {
-		pk_backend_repo_detail (backend, "local",
-					"Local PackageKit volume", _repo_enabled_local);
-	}
 	pk_backend_repo_detail (backend, "fedora",
 				"Fedora - 9", _repo_enabled_fedora);
 	if (!pk_bitfield_contain (filters, PK_FILTER_ENUM_NOT_DEVELOPMENT)) {
@@ -817,29 +845,6 @@ backend_repo_set_data (PkBackend *backend, const gchar *rid, const gchar *parame
 	pk_backend_finished (backend);
 }
 
-/**
- * backend_service_pack:
- */
-static void
-backend_service_pack (PkBackend *backend, const gchar *location, gboolean enabled)
-{
-	pk_backend_set_status (backend, PK_STATUS_ENUM_RUNNING);
-	egg_warning ("service pack %i on %s device", enabled, location);
-
-	/*
-	 * VERY IMPORTANT: THE REPO MUST BE DISABLED IF IT IS ADDED!
-	 * (else it's a security flaw, think of a user with a malicious USB key)
-	 */
-	if (enabled) {
-		_repo_enabled_local = FALSE;
-		/* we tell the daemon what the new repo is called */
-		pk_backend_repo_detail (backend, "local", NULL, FALSE);
-	}
-	_has_service_pack = enabled;
-
-	pk_backend_finished (backend);
-}
-
 /**
  * backend_what_provides_timeout:
  */
@@ -941,6 +946,7 @@ PK_BACKEND_OPTIONS (
 	backend_get_mime_types,			/* get_mime_types */
 	backend_cancel,				/* cancel */
 	backend_download_packages,		/* download_packages */
+	NULL,					/* get_categories */
 	backend_get_depends,			/* get_depends */
 	backend_get_details,			/* get_details */
 	backend_get_distro_upgrades,		/* get_distro_upgrades */
@@ -963,7 +969,6 @@ PK_BACKEND_OPTIONS (
 	backend_search_file,			/* search_file */
 	backend_search_group,			/* search_group */
 	backend_search_name,			/* search_name */
-	backend_service_pack,			/* service_pack */
 	backend_update_packages,		/* update_packages */
 	backend_update_system,			/* update_system */
 	backend_what_provides			/* what_provides */
