@@ -23,10 +23,10 @@
 #include <gmodule.h>
 #include <glib.h>
 #include <string.h>
+#include <packagekit-glib/packagekit.h>
 #include <pk-backend.h>
 #include <pk-backend-internal.h>
 #include <egg-debug.h>
-#include <pk-package-ids.h>
 #include <pk-enum.h>
 
 #include <libopkg/opkg.h>
@@ -724,6 +724,7 @@ PK_BACKEND_OPTIONS (
 	NULL,					/* get_mime_types */
 	NULL,					/* cancel */
 	NULL,					/* download_packages */
+	NULL,					/* get_categories */
 	NULL,					/* get_depends */
 	backend_get_details,			/* get_details */
 	NULL,					/* get_distro_upgrades */
@@ -746,7 +747,6 @@ PK_BACKEND_OPTIONS (
 	NULL,					/* search_file */
 	backend_search_group,			/* search_group */
 	backend_search_name,			/* search_name */
-	NULL,					/* service_pack */
 	backend_update_packages,		/* update_packages */
 	backend_update_system,			/* update_system */
 	NULL					/* what_provides */
