@@ -19,8 +19,8 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
+#include <packagekit-glib/packagekit.h>
 #include <pk-backend.h>
-#include <pk-package-ids.h>
 
 #include <log.h>
 #include <capreq.h>
@@ -2850,6 +2850,7 @@ PK_BACKEND_OPTIONS (
 	NULL,						/* get_mime_types */
 	backend_get_cancel,				/* cancel */
 	backend_download_packages,			/* download_packages */
+	NULL,						/* get_categories */
 	backend_get_depends,				/* get_depends */
 	backend_get_details,				/* get_details */
 	NULL,						/* get_distro_upgrades */
@@ -2872,7 +2873,6 @@ PK_BACKEND_OPTIONS (
 	backend_search_file,				/* search_file */
 	backend_search_group,				/* search_group */
 	backend_search_name,				/* search_name */
-	NULL,						/* service pack */
 	backend_update_packages,			/* update_packages */
 	backend_update_system,				/* update_system */
 	backend_what_provides				/* what_provides */
