@@ -20,10 +20,9 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
+#include <packagekit-glib/packagekit.h>
 #include <pk-backend.h>
 #include <pk-backend-spawn.h>
-#include <pk-package-ids.h>
-#include <pk-common.h>
 
 static PkBackendSpawn *spawn;
 
@@ -467,6 +466,7 @@ PK_BACKEND_OPTIONS (
 	backend_get_mime_types,				/* get_mime_types */
 	backend_cancel,					/* cancel */
 	backend_download_packages,			/* download_packages */
+	NULL,						/* get_categories */
 	backend_get_depends,				/* get_depends */
 	backend_get_details,				/* get_details */
 	NULL,						/* get_distro_upgrades */
@@ -489,7 +489,6 @@ PK_BACKEND_OPTIONS (
 	backend_search_file,				/* search_file */
 	backend_search_group,				/* search_group */
 	backend_search_name,				/* search_name */
-	NULL,						/* service_pack */
 	backend_update_packages,			/* update_packages */
 	backend_update_system,				/* update_system */
 	backend_what_provides				/* what_provides */
