@@ -289,15 +289,6 @@ backend_repo_set_data (PkBackend *backend, const gchar *rid, const gchar *parame
 	pk_backend_finished (backend);
 }
 
-/**
- * backend_service_pack:
- */
-static void
-backend_service_pack (PkBackend *backend, const gchar *location, gboolean enabled)
-{
-	pk_backend_finished (backend);
-}
-
 /**
  * backend_what_provides:
  */
@@ -326,6 +317,7 @@ PK_BACKEND_OPTIONS (
 	NULL,					/* get_mime_types */
 	backend_cancel,				/* cancel */
 	NULL,					/* download_packages */
+	NULL,					/* get_categories */
 	backend_get_depends,			/* get_depends */
 	backend_get_details,			/* get_details */
 	NULL,					/* get_distro_upgrades */
@@ -348,7 +340,6 @@ PK_BACKEND_OPTIONS (
 	backend_search_file,			/* search_file */
 	backend_search_group,			/* search_group */
 	backend_search_name,			/* search_name */
-	backend_service_pack,			/* service_pack */
 	backend_update_packages,		/* update_packages */
 	backend_update_system,			/* update_system */
 	backend_what_provides			/* what_provides */
