@@ -19,13 +19,27 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
+#include <packagekit-glib/packagekit.h>
 #include <pk-backend.h>
 #include <pk-backend-spawn.h>
-#include <pk-package-ids.h>
-#include <pk-common.h>
+#include <string.h>
 
 static PkBackendSpawn *spawn;
 
+/**
+ * backend_stderr_cb:
+ */
+static gboolean
+backend_stderr_cb (PkBackend *backend, const gchar *output)
+{
+	/* unsigned rpm, this will be picked up by yum and and exception will be thrown */
+	if (strstr (output, "NOKEY") != NULL)
+		return FALSE;
+	if (strstr (output, "GPG") != NULL)
+		return FALSE;
+	return TRUE;
+}
+
 /**
  * backend_initialize:
  * This should only be run once per backend load, i.e. not every transaction
@@ -35,6 +49,7 @@ backend_initialize (PkBackend *backend)
 {
 	egg_debug ("backend: initialize");
 	spawn = pk_backend_spawn_new ();
+	pk_backend_spawn_set_filter_stderr (spawn, backend_stderr_cb);
 	pk_backend_spawn_set_name (spawn, "yum");
 }
 
@@ -57,6 +72,7 @@ backend_get_groups (PkBackend *backend)
 {
 	return pk_bitfield_from_enums (
 		PK_GROUP_ENUM_COLLECTIONS,
+		PK_GROUP_ENUM_NEWEST,
 		PK_GROUP_ENUM_ADMIN_TOOLS,
 		PK_GROUP_ENUM_DESKTOP_GNOME,
 		PK_GROUP_ENUM_DESKTOP_KDE,
@@ -459,6 +475,15 @@ backend_what_provides (PkBackend *backend, PkBitfield filters, PkProvidesEnum pr
 	g_free (filters_text);
 }
 
+/**
+ * pk_backend_get_categories:
+ */
+static void
+backend_get_categories (PkBackend *backend)
+{
+	pk_backend_spawn_helper (spawn, "yumBackend.py", "get-categories", NULL);
+}
+
 PK_BACKEND_OPTIONS (
 	"YUM",					/* description */
 	"Tim Lauridsen <timlau@fedoraproject.org>, Richard Hughes <richard@hughsie.com>",	/* author */
@@ -469,6 +494,7 @@ PK_BACKEND_OPTIONS (
 	backend_get_mime_types,			/* get_mime_types */
 	backend_cancel,				/* cancel */
 	backend_download_packages,		/* download_packages */
+	backend_get_categories,			/* get_categories */
 	backend_get_depends,			/* get_depends */
 	backend_get_details,			/* get_details */
 	backend_get_distro_upgrades,		/* get_distro_upgrades */
@@ -491,7 +517,6 @@ PK_BACKEND_OPTIONS (
 	backend_search_file,			/* search_file */
 	backend_search_group,			/* search_group */
 	backend_search_name,			/* search_name */
-	NULL,					/* service_pack */
 	backend_update_packages,		/* update_packages */
 	backend_update_system,			/* update_system */
 	backend_what_provides			/* what_provides */
