@@ -19,13 +19,15 @@
 #    Richard Hughes <richard@hughsie.com>
 
 from packagekit.enums import *
-import sqlite3 as sqlite
+import sqlite3
 import os
+import yum
 
 groupMap = {
 'desktops;gnome-desktop'                      : GROUP_DESKTOP_GNOME,
 'desktops;window-managers'                    : GROUP_DESKTOP_OTHER,
 'desktops;sugar-desktop'                      : GROUP_DESKTOP_OTHER,
+'desktops;lxde-desktop'                       : GROUP_DESKTOP_OTHER,
 'desktops;kde-desktop'                        : GROUP_DESKTOP_KDE,
 'desktops;xfce-desktop'                       : GROUP_DESKTOP_XFCE,
 'apps;authoring-and-publishing'               : GROUP_PUBLISHING,
@@ -38,6 +40,7 @@ groupMap = {
 'apps;text-internet'                          : GROUP_INTERNET,
 'apps;graphical-internet'                     : GROUP_INTERNET,
 'apps;education'                              : GROUP_EDUCATION,
+'development;haskell'                         : GROUP_PROGRAMMING,
 'development;kde-software-development'        : GROUP_PROGRAMMING,
 'development;gnome-software-development'      : GROUP_PROGRAMMING,
 'development;development-tools'               : GROUP_PROGRAMMING,
@@ -63,6 +66,7 @@ groupMap = {
 'servers;mail-server'                         : GROUP_SERVERS,
 'servers;network-server'                      : GROUP_SERVERS,
 'servers;legacy-network-server'               : GROUP_SERVERS,
+'base-system;input-methods'                   : GROUP_LOCALIZATION,
 'base-system;java'                            : GROUP_SYSTEM,
 'base-system;base-x'                          : GROUP_SYSTEM,
 'base-system;system-tools'                    : GROUP_ADMIN_TOOLS,
@@ -169,6 +173,13 @@ groupMap = {
 'language-support;macedonian-support'         : GROUP_LOCALIZATION,
 'language-support;walloon-support'            : GROUP_LOCALIZATION,
 'language-support;kashubian-support'          : GROUP_LOCALIZATION,
+'language-support;kashmiri-support'           : GROUP_LOCALIZATION,
+'language-support;konkani-support'            : GROUP_LOCALIZATION,
+'language-support;tajik-support'              : GROUP_LOCALIZATION,
+'language-support;sindhi-support'             : GROUP_LOCALIZATION,
+'language-support;uzbek-support'              : GROUP_LOCALIZATION,
+'language-support;burmese-support'            : GROUP_LOCALIZATION,
+'language-support;maithili-support'           : GROUP_LOCALIZATION,
 'rpmfusion_free;kde-desktop'                  : GROUP_DESKTOP_KDE,
 'rpmfusion_free;misc-libs'                    : GROUP_OTHER,
 'rpmfusion_free;games'                        : GROUP_GAMES,
@@ -194,14 +205,14 @@ class yumComps:
         self.cursor = None
         self.connection = None
         if not db:
-            db = '/var/cache/yum/packagekit-groups.sqlite'
+            db = '/var/cache/PackageKit/groups.sqlite'
         self.db = db
 
     def connect(self):
         ''' connect to database '''
         try:
             # will be created if it does not exist
-            self.connection = sqlite.connect(self.db)
+            self.connection = sqlite3.connect(self.db)
             self.cursor = self.connection.cursor()
         except Exception, e:
             print 'cannot connect to database %s: %s' % (self.db, str(e))
@@ -229,7 +240,7 @@ class yumComps:
         try: # kill the old db
             self.connection.close()
             os.unlink(self.db) # kill the db
-            self.connection = sqlite.connect(self.db)
+            self.connection = sqlite3.connect(self.db)
             self.cursor = self.connection.cursor()
         except Exception, e:
             print e
@@ -245,8 +256,10 @@ class yumComps:
 
     def refresh(self, force=False):
         ''' get the data from yum (slow, REALLY SLOW) '''
-
-        cats = self.yumbase.comps.categories
+        try:
+            cats = self.yumbase.comps.categories
+        except yum.Errors.RepoError, e:
+            return False
         if self.yumbase.comps.compscount == 0:
             return False
 
@@ -257,31 +270,49 @@ class yumComps:
         for category in cats:
             grps = map(lambda x: self.yumbase.comps.return_group(x),
                filter(lambda x: self.yumbase.comps.has_group(x), category.groups))
-            for group in grps:
-
-                # strip out rpmfusion from the group name
-                group_name = group.groupid
-                group_name = group_name.replace('rpmfusion_nonfree-', '')
-                group_name = group_name.replace('rpmfusion_free-', '')
-                group_id = "%s;%s" % (category.categoryid, group_name)
-
-                group_enum = GROUP_OTHER
-                if groupMap.has_key(group_id):
-                    group_enum = groupMap[group_id]
-                else:
-                    print 'unknown group enum', group_id
-
-                for package in group.mandatory_packages:
-                    self._add_db(package, category.categoryid, group_name, group_enum, 'mandatory')
-                for package in group.default_packages:
-                    self._add_db(package, category.categoryid, group_name, group_enum, 'default')
-                for package in group.optional_packages:
-                    self._add_db(package, category.categoryid, group_name, group_enum, 'optional')
+            self._add_groups_to_db(grps, category.categoryid)
 
         # write to disk
         self.connection.commit()
+        print "Non Categorized groups"
+        self._add_non_catagorized_groups()
+        self.connection.commit()
         return True
 
+    def _add_groups_to_db(self, grps, cat_id):
+        for group in grps:
+            # strip out rpmfusion from the group name
+            group_name = group.groupid
+            group_name = group_name.replace('rpmfusion_nonfree-', '')
+            group_name = group_name.replace('rpmfusion_free-', '')
+            group_id = "%s;%s" % (cat_id, group_name)
+
+            group_enum = GROUP_OTHER
+            if groupMap.has_key(group_id):
+                group_enum = groupMap[group_id]
+            else:
+                print 'unknown group enum', group_id
+
+            for package in group.mandatory_packages:
+                self._add_db(package, cat_id, group_name, group_enum, 'mandatory')
+            for package in group.default_packages:
+                self._add_db(package, cat_id, group_name, group_enum, 'default')
+            for package in group.optional_packages:
+                self._add_db(package, cat_id, group_name, group_enum, 'optional')
+
+
+    def _add_non_catagorized_groups(self):
+        to_add = []
+        # Go through all the groups
+        for grp in self.yumbase.comps.groups:
+            # check if it is already added to the db
+            if self.get_category(grp.groupid):
+                continue
+            elif grp.user_visible:
+                to_add.append(grp)
+        self._add_groups_to_db(to_add, "other")
+
+
     def get_package_list(self, group_key):
         ''' for a PK group, get the packagelist for this group '''
         all_packages = []
@@ -310,7 +341,7 @@ class yumComps:
     def get_meta_package_list(self, groupid):
         ''' for a comps group, get the packagelist for this group (mandatory, default)'''
         all_packages = []
-        self.cursor.execute('SELECT name FROM groups WHERE groupid = ? AND ( pkgtype = "mandatory" OR pkgtype = "default");', [groupid])
+        self.cursor.execute('SELECT name FROM groups WHERE groupid = ? ;', [groupid])
         for row in self.cursor:
             all_packages.append(row[0])
         return all_packages
@@ -324,13 +355,18 @@ class yumComps:
             break
         return category
 
-if __name__ == "__main__":
-    import yum
+    def get_groups(self, cat_id):
+        grps = set()
+        self.cursor.execute('SELECT groupid FROM groups WHERE category = ?', [cat_id])
+        for row in self.cursor:
+            grps.add(row[0])
+        return list(grps)
+
+def main():
     _yb = yum.YumBase()
-    _db = "./packagekit-groups.sqlite"
+    _db = "/var/cache/yum/packagekit-groups.sqlite"
     comps = yumComps(_yb, _db)
     comps.connect()
-    comps.refresh()
     print "pk group system"
     print 40 * "="
     _pkgs = comps.get_package_list('system')
@@ -343,5 +379,12 @@ if __name__ == "__main__":
     print 40 * "="
     _pkgs = comps.get_meta_package_list('kde-desktop')
     print _pkgs
+    print "comps group other"
+    print 40 * "="
+    _pkgs = comps.get_groups('other')
+    print _pkgs
     os.unlink(_db) # kill the db
 
+if __name__ == "__main__":
+    main()
+
