@@ -27,6 +27,7 @@
 #include <string>
 #include <set>
 #include <glib/gi18n.h>
+#include <packagekit-glib/packagekit.h>
 
 #include <zypp/ZYppFactory.h>
 #include <zypp/ResObject.h>
@@ -48,6 +49,8 @@
 #include <zypp/target/rpm/RpmDb.h>
 #include <zypp/target/rpm/RpmHeader.h>
 #include <zypp/target/rpm/RpmException.h>
+#include <zypp/base/Functional.h>
+#include <zypp/parser/ProductFileReader.h>
 #include <zypp/TmpPath.h>
 
 #include <zypp/sat/Solvable.h>
@@ -55,8 +58,6 @@
 #include <map>
 #include <list>
 
-#include <pk-package-ids.h>
-
 #include "zypp-utils.h"
 #include "zypp-events.h"
 
@@ -137,12 +138,12 @@ backend_get_requires_thread (PkBackend *backend)
 	}
 
 	pk_backend_set_status (backend, PK_STATUS_ENUM_QUERY);
-	
+
 	//TODO repair percentages
 	//pk_backend_set_percentage (backend, 0);
 
 	for (uint i = 0; i < g_strv_length(package_ids); i++) {
-		
+
 		pi = pk_package_id_new_from_string (package_ids[i]);
 
 		zypp::sat::Solvable solvable = zypp_get_package_by_id (package_ids[i]);
@@ -280,7 +281,6 @@ backend_get_groups (PkBackend *backend)
 		PK_GROUP_ENUM_PUBLISHING,
 		PK_GROUP_ENUM_SECURITY,
 		PK_GROUP_ENUM_SYSTEM,
-		PK_GROUP_ENUM_UNKNOWN,
 		-1);
 }
 
@@ -575,38 +575,33 @@ static gboolean
 backend_get_distro_upgrades_thread(PkBackend *backend)
 {
 	pk_backend_set_status (backend, PK_STATUS_ENUM_QUERY);
-	pk_backend_set_percentage (backend, 0);
 
-	// refresh the repos before checking for updates
-	if (!zypp_refresh_cache (backend, FALSE)) {
+	std::vector<zypp::parser::ProductFileData> result;
+	if (!zypp::parser::ProductFileReader::scanDir (zypp::functor::getAll (std::back_inserter (result)), "/etc/products.d")) {
+		pk_backend_error_code (backend, PK_ERROR_ENUM_INTERNAL_ERROR, "Could not parse /etc/products.d");
 		pk_backend_finished (backend);
 		return FALSE;
 	}
 
-	zypp::ResPool pool = zypp_build_pool (TRUE);
-	pk_backend_set_percentage (backend, 40);
-
-	// get all Packages and Patches for Update
-	std::set<zypp::PoolItem> *candidates = zypp_get_patches ();
-
-	pk_backend_set_percentage (backend, 80);
-
-	std::set<zypp::PoolItem>::iterator cb = candidates->begin (), ce = candidates->end (), ci;
-	for (ci = cb; ci != ce; ++ci) {
-		zypp::ResObject::constPtr res = ci->resolvable();
-
-		if (zypp::isKind<zypp::Patch>(res)) {
-			zypp::Patch::constPtr patch = zypp::asKind<zypp::Patch>(res);
-			if (patch->category () == "distupgrade")
-			{
-				// here emit a distupgrade available using the patch summary
-				pk_backend_distro_upgrade(backend,
-							PK_DISTRO_UPGRADE_ENUM_STABLE,
-							patch->name ().c_str (),
-							patch->summary ().c_str ());
+	for (std::vector<zypp::parser::ProductFileData>::iterator it = result.begin (); it != result.end (); it++) {
+		std::vector<zypp::parser::ProductFileData::Upgrade> upgrades = it->upgrades();
+		for (std::vector<zypp::parser::ProductFileData::Upgrade>::iterator it2 = upgrades.begin (); it2 != upgrades.end (); it2++) {
+			if (it2->notify ()){
+				PkDistroUpgradeEnum status = PK_DISTRO_UPGRADE_ENUM_UNKNOWN;
+				if (it2->status () == "stable") {
+					status = PK_DISTRO_UPGRADE_ENUM_STABLE;
+				} else if (it2->status () == "unstable") {
+					status = PK_DISTRO_UPGRADE_ENUM_UNSTABLE;
+				}
+				pk_backend_distro_upgrade (backend,
+							   status,
+							   it2->name ().c_str (),
+							   it2->summary ().c_str ());
 			}
 		}
 	}
+
+	pk_backend_finished (backend);
 	return TRUE;
 }
 
@@ -640,7 +635,7 @@ backend_refresh_cache (PkBackend *backend, gboolean force)
 /* If a critical self update (see qualifying steps below) is available then only show/install that update first.
  1. there is a patch available with the <restart_suggested> tag set
  2. The patch contains the package "PackageKit" or "gnome-packagekit
-*/   
+*/
 /*static gboolean
 check_for_self_update (PkBackend *backend, std::set<zypp::PoolItem> *candidates)
 {
@@ -678,7 +673,7 @@ backend_get_updates_thread (PkBackend *backend)
 	zypp::ResPool pool = zypp_build_pool (TRUE);
 	pk_backend_set_percentage (backend, 40);
 
-	// check if the repositories may be dead (feature #301904)  
+	// check if the repositories may be dead (feature #301904)
 	 warn_outdated_repos(backend, pool);
 
 	// get all Packages and Patches for Update
@@ -691,14 +686,14 @@ backend_get_updates_thread (PkBackend *backend)
 		if (!candidates->empty ()) {
 			patchRepo = candidates->begin ()->resolvable ()->repoInfo ().alias ();
 		}
-		
+
 		//candidates2 = zypp_get_updates (patchRepo);
 
 		//candidates->insert (candidates2->begin (), candidates2->end ());
 	}
 
 	pk_backend_set_percentage (backend, 80);
-	
+
 	std::set<zypp::PoolItem>::iterator cb = candidates->begin (), ce = candidates->end (), ci;
 	for (ci = cb; ci != ce; ++ci) {
 		zypp::ResObject::constPtr res = ci->resolvable();
@@ -781,7 +776,7 @@ backend_install_files_thread (PkBackend *backend)
 			return FALSE;
 		}
 	}
-	
+
 	// create a plaindir-repo and cache it
 	zypp::RepoInfo tmpRepo;
 
@@ -793,6 +788,7 @@ backend_install_files_thread (PkBackend *backend)
 		tmpRepo.setAutorefresh (true);
 		tmpRepo.setAlias ("PK_TMP_DIR");
 		tmpRepo.setName ("PK_TMP_DIR");
+		zypp_build_pool(true);
 
 		// add Repo to pool
 
@@ -815,10 +811,10 @@ backend_install_files_thread (PkBackend *backend)
 	}
 
 	for (guint i = 0; i < g_strv_length (full_paths); i++) {
-		
+
 		zypp::Pathname rpmPath (full_paths[i]);
 		zypp::target::rpm::RpmHeader::constPtr rpmHeader = zypp::target::rpm::RpmHeader::readPackage (rpmPath, zypp::target::rpm::RpmHeader::NOSIGNATURE);
-		
+
 		// look for the packages and set them to toBeInstalled
 		std::vector<zypp::sat::Solvable> *solvables = new std::vector<zypp::sat::Solvable>;
 		solvables = zypp_get_packages_by_name (rpmHeader->tag_name ().c_str (), zypp::ResKind::package, FALSE);
@@ -898,13 +894,7 @@ backend_get_update_detail_thread (PkBackend *backend)
 
 		if (zypp::isKind<zypp::Patch>(solvable)) {
 			zypp::Patch::constPtr patch = zypp::asKind<zypp::Patch>(item);
-			if (patch->rebootSuggested ()) {
-				restart = PK_RESTART_ENUM_SYSTEM;
-			} else if (patch->restartSuggested ()) {
-				restart = PK_RESTART_ENUM_SESSION;
-			} else if (patch->reloginSuggested()) {
-				restart = PK_RESTART_ENUM_SESSION;
-			}
+			zypp_get_restart (restart, patch);
 
 			// Building links like "http://www.distro-update.org/page?moo;Bugfix release for kernel;http://www.test.de/bgz;test domain"
 			for (zypp::Patch::ReferenceIterator it = patch->referencesBegin (); it != patch->referencesEnd (); it ++) {
@@ -978,9 +968,9 @@ backend_update_system_thread (PkBackend *backend)
 	PkRestartEnum restart = PK_RESTART_ENUM_NONE;
 
 	//get all Patches for Update
-	std::set<zypp::PoolItem> *candidates = zypp_get_patches (restart);
+	std::set<zypp::PoolItem> *candidates = zypp_get_patches ();
 	//std::set<zypp::PoolItem> *candidates2 = new std::set<zypp::PoolItem> ();
-	
+
 	if (_updating_self) {
 		_updating_self = FALSE;
 	}
@@ -990,7 +980,7 @@ backend_update_system_thread (PkBackend *backend)
 		if (!candidates->empty ()) {
 			patchRepo = candidates->begin ()->resolvable ()->repoInfo ().alias ();
 		}
-	
+
 		//get all Updates
 		//candidates2 = zypp_get_updates (patchRepo);
 
@@ -998,13 +988,14 @@ backend_update_system_thread (PkBackend *backend)
 
 		//candidates->insert (candidates2->begin (), candidates2->end ());
 	}
-	
+
 	pk_backend_set_percentage (backend, 80);
 	std::set<zypp::PoolItem>::iterator cb = candidates->begin (), ce = candidates->end (), ci;
 	for (ci = cb; ci != ce; ++ci) {
 		// set the status of the update to ToBeInstalled
 		zypp::ResStatus &status = ci->status ();
 		status.setToBeInstalled (zypp::ResStatus::USER);
+		zypp_get_restart (restart, zypp::asKind<zypp::Patch>(ci->resolvable ()));
 	}
 
 	if (!zypp_perform_execution (backend, UPDATE, FALSE)) {
@@ -1012,7 +1003,7 @@ backend_update_system_thread (PkBackend *backend)
 		pk_backend_finished (backend);
 		return FALSE;
 	}
-	
+
 	if (restart != PK_RESTART_ENUM_NONE)
 		pk_backend_require_restart (backend, restart, "A restart is needed");
 
@@ -1039,12 +1030,12 @@ backend_install_packages_thread (PkBackend *backend)
 
 	pk_backend_set_status (backend, PK_STATUS_ENUM_QUERY);
 	pk_backend_set_percentage (backend, 0);
-	
+
 	zypp::ZYpp::Ptr zypp;
 	zypp = get_zypp ();
 
 	package_ids = pk_backend_get_strv (backend, "package_ids");
-	
+
 	try
 	{
 		zypp::ResPool pool = zypp_build_pool (TRUE);
@@ -1133,6 +1124,7 @@ backend_install_packages (PkBackend *backend, gchar **package_ids)
 static gboolean
 backend_install_signature_thread (PkBackend *backend)
 {
+	pk_backend_set_status (backend, PK_STATUS_ENUM_SIG_CHECK);
 	const gchar *key_id = pk_backend_get_string (backend, "key_id");
 	_signatures[backend]->push_back ((std::string)(key_id));
 
@@ -1158,7 +1150,7 @@ backend_remove_packages_thread (PkBackend *backend)
 
 	pk_backend_set_status (backend, PK_STATUS_ENUM_REMOVE);
 	pk_backend_set_percentage (backend, 0);
-	
+
 	zypp::Target_Ptr target;
 	zypp::ZYpp::Ptr zypp;
 	zypp = get_zypp ();
@@ -1239,6 +1231,8 @@ static gboolean
 backend_resolve_thread (PkBackend *backend)
 {
 	gchar **package_ids = pk_backend_get_strv (backend, "package_ids");
+	PkBitfield filters_field = (PkBitfield) pk_backend_get_uint (backend, "filters");
+	gchar *filters = pk_filter_bitfield_to_text(filters_field);
 
 	pk_backend_set_status (backend, PK_STATUS_ENUM_QUERY);
 
@@ -1265,6 +1259,7 @@ backend_resolve_thread (PkBackend *backend)
 		delete (v2);
 
 		if (package == NULL) {
+			g_free (filters);
 			pk_backend_error_code (backend, PK_ERROR_ENUM_PACKAGE_NOT_FOUND, "couldn't find package");
 			pk_backend_finished (backend);
 			return FALSE;
@@ -1273,8 +1268,14 @@ backend_resolve_thread (PkBackend *backend)
 		const gchar *package_id = zypp_build_package_id_from_resolvable (package);
 
 		PkInfoEnum info = PK_INFO_ENUM_AVAILABLE;
-		if( package.isSystem ())
+		if( package.isSystem ()){
 			info = PK_INFO_ENUM_INSTALLED;
+			if (g_strrstr (filters, "~installed") != NULL)
+				continue;
+		}else{
+			if (g_strrstr (filters, "~installed") == NULL)
+				continue;
+		}
 
 		pk_backend_package (backend,
 				    info,
@@ -1282,6 +1283,7 @@ backend_resolve_thread (PkBackend *backend)
 				    package.lookupStrAttribute (zypp::sat::SolvAttr::summary).c_str ());
 	}
 
+	g_free (filters);
 	pk_backend_finished (backend);
 	return TRUE;
 }
@@ -1492,7 +1494,7 @@ backend_get_files_thread (PkBackend *backend)
 	gchar **package_ids;
 
 	package_ids = pk_backend_get_strv (backend, "package_ids");
-	
+
 	for(uint i = 0; i < g_strv_length(package_ids); i++) {
 		pi = pk_package_id_new_from_string (package_ids[i]);
 		if (pi == NULL) {
@@ -1610,7 +1612,7 @@ backend_update_packages_thread (PkBackend *backend)
 	package_ids = pk_backend_get_strv (backend, "package_ids");
 	PkRestartEnum restart = PK_RESTART_ENUM_NONE;
 
-	zypp_get_patches (restart); // make shure _updating_self is set
+	zypp_get_patches (); // make sure _updating_self is set
 
 	if (_updating_self) {
 		egg_debug ("updating self and setting restart");
@@ -1621,11 +1623,13 @@ backend_update_packages_thread (PkBackend *backend)
 		zypp::sat::Solvable solvable = zypp_get_package_by_id (package_ids[i]);
 		zypp::PoolItem item = zypp::ResPool::instance ().find (solvable);
 		item.status ().setToBeInstalled (zypp::ResStatus::USER);
+		zypp::Patch::constPtr patch = zypp::asKind<zypp::Patch>(item.resolvable ());
+		zypp_get_restart (restart, patch);
 	}
 
 	retval = zypp_perform_execution (backend, UPDATE, FALSE);
 	pk_backend_finished (backend);
-	
+
 	if (restart != PK_RESTART_ENUM_NONE)
 		pk_backend_require_restart (backend, restart, "A restart is needed");
 
@@ -1761,6 +1765,8 @@ backend_what_provides_thread (PkBackend *backend)
 	const gchar *search;
 	search = pk_backend_get_string (backend, "search");
 	PkProvidesEnum provides = (PkProvidesEnum) pk_backend_get_uint (backend, "provides");
+	PkBitfield filters_field = (PkBitfield) pk_backend_get_uint (backend, "filters");
+	gchar *filters = pk_filter_bitfield_to_text(filters_field);
 	zypp::Capability cap (search);
 	zypp::sat::WhatProvides prov (cap);
 
@@ -1776,6 +1782,7 @@ backend_what_provides_thread (PkBackend *backend)
 				egg_warning("Solver problem (This should never happen): '%s'", (*it)->description ().c_str ());
 			}
 			solver.setIgnoreAlreadyRecommended (FALSE);
+			g_free (filters);
 			pk_backend_error_code (backend, PK_ERROR_ENUM_DEP_RESOLUTION_FAILED, "Resolution failed");
 			pk_backend_finished (backend);
 			return FALSE;
@@ -1794,6 +1801,9 @@ backend_what_provides_thread (PkBackend *backend)
 			}
 
 			if (hit) {
+				if (g_strrstr(filters, "~installed") != NULL)
+					continue;
+
 				gchar *package_id;
 				package_id = pk_package_id_build ( it->resolvable ()->name ().c_str(),
 						it->resolvable ()->edition ().asString ().c_str(),
@@ -1812,13 +1822,19 @@ backend_what_provides_thread (PkBackend *backend)
 			gchar *package_id = zypp_build_package_id_from_resolvable (*it);
 
 			PkInfoEnum info = PK_INFO_ENUM_AVAILABLE;
-			if( it->isSystem ())
+			if( it->isSystem ()){
 				info = PK_INFO_ENUM_INSTALLED;
-
+				if (g_strrstr (filters, "~installed") != NULL)
+					continue;
+			}else{
+				if (g_strrstr (filters, "~installed") == NULL)
+					continue;
+			}
 			pk_backend_package (backend, info, package_id, it->lookupStrAttribute (zypp::sat::SolvAttr::summary).c_str ());
 		}
 	}
 
+	g_free (filters);
 	pk_backend_finished (backend);
 	return TRUE;
 }
@@ -1844,6 +1860,7 @@ extern "C" PK_BACKEND_OPTIONS (
 	NULL,					/* get_mime_types */
 	NULL,					/* cancel */
 	NULL,					/* download_packages */
+	NULL,					/* get_categories */
 	backend_get_depends,			/* get_depends */
 	backend_get_details,			/* get_details */
 	backend_get_distro_upgrades,		/* get_distro_upgrades */
@@ -1866,7 +1883,6 @@ extern "C" PK_BACKEND_OPTIONS (
 	backend_search_file,			/* search_file */
 	backend_search_group,			/* search_group */
 	backend_search_name,			/* search_name */
-	NULL,					/* service_pack */
 	backend_update_packages,		/* update_packages */
 	backend_update_system,			/* update_system */
 	backend_what_provides			/* what_provides */
