@@ -53,7 +53,7 @@
 #include <zypp/base/Logger.h>
 
 #include <pk-backend.h>
-#include <pk-package-ids.h>
+#include <packagekit-glib/packagekit.h>
 
 #include "zypp-utils.h"
 
@@ -658,7 +658,7 @@ zypp_get_updates (std::string repo)
 }
 
 std::set<zypp::PoolItem> *
-zypp_get_patches (PkRestartEnum restart)
+zypp_get_patches ()
 {
         std::set<zypp::PoolItem> *patches = new std::set<zypp::PoolItem> ();
 	_updating_self = FALSE;
@@ -680,16 +680,6 @@ zypp_get_patches (PkRestartEnum restart)
 			else
 				patches->insert ((*it)->candidateObj ());
 
-			// set the restart flag if a restart is needed
-			if (restart != PK_RESTART_ENUM_SYSTEM && (patch->reloginSuggested () ||
-								  patch->restartSuggested () ||
-								  patch->rebootSuggested ())) {
-					if(patch->reloginSuggested () || patch->restartSuggested ())
-						restart = PK_RESTART_ENUM_SESSION;
-					if(patch->rebootSuggested ())
-						restart = PK_RESTART_ENUM_SYSTEM;
-			}
-
 			// check if the patch updates libzypp or packageKit and show only these
 			if (!_updating_self && patch->restartSuggested ()) {
 				_updating_self = TRUE;
@@ -704,6 +694,21 @@ zypp_get_patches (PkRestartEnum restart)
 
 }
 
+gboolean
+zypp_get_restart (PkRestartEnum &restart, zypp::Patch::constPtr patch)
+{
+	// set the restart flag if a restart is needed
+	if (restart != PK_RESTART_ENUM_SYSTEM && (patch->reloginSuggested () ||
+						  patch->restartSuggested () ||
+						  patch->rebootSuggested ())) {
+			if(patch->reloginSuggested () || patch->restartSuggested ())
+				restart = PK_RESTART_ENUM_SESSION;
+			if(patch->rebootSuggested ())
+				restart = PK_RESTART_ENUM_SYSTEM;
+	}
+	return true;
+}
+
 gboolean
 zypp_perform_execution (PkBackend *backend, PerformType type, gboolean force)
 {
@@ -923,6 +928,7 @@ zypp_refresh_cache (PkBackend *backend, gboolean force)
 	int i = 1;
 	int num_of_repos = repos.size ();
 	int percentage_increment = 100 / num_of_repos;
+	gchar *repo_messages = NULL;
 
 	for (std::list <zypp::RepoInfo>::iterator it = repos.begin(); it != repos.end(); it++, i++) {
 		zypp::RepoInfo repo (*it);
@@ -943,9 +949,15 @@ zypp_refresh_cache (PkBackend *backend, gboolean force)
 				zypp::RepoManager::RefreshForced :
 				zypp::RepoManager::RefreshIfNeeded);
 		} catch (const zypp::Exception &ex) {
-			pk_backend_error_code (backend, PK_ERROR_ENUM_INTERNAL_ERROR, "%s: %s", repo.alias ().c_str (), ex.asUserString ().c_str ());
-			pk_backend_finished (backend);
-			return FALSE;
+			if (repo_messages == NULL) {
+				repo_messages = g_strdup_printf ("%s: %s%s", repo.alias ().c_str (), ex.asUserString ().c_str (), "\n");	
+			}else{
+				repo_messages = g_strdup_printf ("%s%s: %s%s", repo_messages, repo.alias ().c_str (), ex.asUserString ().c_str (), "\n");	
+			}
+			repo_messages = pk_strsafe (repo_messages);
+			if (repo_messages == NULL)
+				repo_messages = g_strdup ("A repository could not be refreshed");
+			continue;
 		}
 
 		try {
@@ -958,15 +970,22 @@ zypp_refresh_cache (PkBackend *backend, gboolean force)
 		//} catch (const zypp::repo::RepoUnknownTypeException &ex) {
 		//} catch (const zypp::repo::RepoException &ex) {
 		} catch (const zypp::Exception &ex) {
-			// TODO: Handle the exceptions in manager.refreshMetadata
-			pk_backend_error_code (backend, PK_ERROR_ENUM_INTERNAL_ERROR, "%s: %s",
-					       repo.alias ().c_str (), ex.asUserString().c_str() );
-			pk_backend_finished (backend);
-			return FALSE;
+			if (repo_messages == NULL) {
+				repo_messages = g_strdup_printf ("%s: %s%s", repo.alias ().c_str (), ex.asUserString ().c_str (), "\n");	
+			}else{
+				repo_messages = g_strdup_printf ("%s%s: %s%s", repo_messages, repo.alias ().c_str (), ex.asUserString ().c_str (), "\n");	
+			}
+			repo_messages = pk_strsafe (repo_messages);
+			if (repo_messages == NULL)
+				repo_messages = g_strdup ("A repository could not be refreshed");
 		}
 
 		// Update the percentage completed
 		pk_backend_set_percentage (backend, i == num_of_repos ? 100 : i * percentage_increment);
 	}
+	if (repo_messages != NULL)
+		pk_backend_message (backend, PK_MESSAGE_ENUM_CONNECTION_REFUSED, repo_messages);
+
+	g_free (repo_messages);
 	return TRUE;
 }
