@@ -24,15 +24,13 @@
 #include <string.h>
 #include <unistd.h>
 #include <stdlib.h>
+#include <locale.h>
 #include <glib.h>
 #include <glib/gi18n.h>
 #include <dbus/dbus-glib.h>
+#include <packagekit-glib/packagekit.h>
 
-#include <egg-debug.h>
-#include <pk-common.h>
-#include <pk-control.h>
-#include <pk-task-list.h>
-#include <pk-connection.h>
+#include "egg-debug.h"
 
 /**
  * pk_monitor_task_list_changed_cb:
@@ -90,11 +88,10 @@ pk_connection_changed_cb (PkConnection *pconnection, gboolean connected, gpointe
 static void
 pk_monitor_locked_cb (PkControl *control, gboolean is_locked, gpointer data)
 {
-	if (is_locked) {
+	if (is_locked)
 		g_print ("locked\n");
-	} else {
+	else
 		g_print ("unlocked\n");
-	}
 }
 
 /**
@@ -121,9 +118,13 @@ main (int argc, char *argv[])
 		{ NULL}
 	};
 
-	if (! g_thread_supported ()) {
+	setlocale (LC_ALL, "");
+	bindtextdomain (GETTEXT_PACKAGE, PACKAGE_LOCALE_DIR);
+	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+	textdomain (GETTEXT_PACKAGE);
+
+	if (! g_thread_supported ())
 		g_thread_init (NULL);
-	}
 	dbus_g_thread_init ();
 	g_type_init ();
 
@@ -162,13 +163,14 @@ main (int argc, char *argv[])
 	g_signal_connect (tlist, "status-changed",
 			  G_CALLBACK (pk_monitor_task_list_changed_cb), NULL);
 
+
 	egg_debug ("refreshing task list");
 	ret = pk_task_list_refresh (tlist);
-	if (ret == FALSE) {
+	if (!ret)
 		g_error ("cannot refresh transaction list");
-	}
 	pk_task_list_print (tlist);
 
+	/* spin */
 	g_main_loop_run (loop);
 
 	g_object_unref (control);
