@@ -41,11 +41,7 @@
 #include <gmodule.h>
 #include <egg-dbus-monitor.h>
 #include <dbus/dbus-glib.h>
-
-#include <pk-common.h>
-#include <pk-package-id.h>
-#include <pk-enum.h>
-#include <pk-network.h>
+#include <packagekit-glib/packagekit.h>
 
 #include "egg-debug.h"
 #include "pk-backend-internal.h"
@@ -163,6 +159,17 @@ pk_backend_dbus_distro_upgrade_cb (DBusGProxy *proxy,
 				   name, summary);
 }
 
+/**
+ * pk_backend_dbus_category_cb:
+ **/
+static void
+pk_backend_dbus_category_cb (DBusGProxy *proxy, const gchar *parent_id, const gchar *cat_id, const gchar *name,
+			     const gchar *summary, const gchar *icon, PkBackendDbus *backend_dbus)
+{
+	egg_debug ("got signal");
+	pk_backend_category (backend_dbus->priv->backend, parent_id, cat_id, name, summary, icon);
+}
+
 /**
  * pk_backend_dbus_files_cb:
  **/
@@ -358,6 +365,8 @@ pk_backend_dbus_remove_callbacks (PkBackendDbus *backend_dbus)
 					G_CALLBACK (pk_backend_dbus_repo_signature_required_cb), backend_dbus);
 	dbus_g_proxy_disconnect_signal (proxy, "EulaRequired",
 					G_CALLBACK (pk_backend_dbus_eula_required_cb), backend_dbus);
+	dbus_g_proxy_disconnect_signal (proxy, "Category",
+					G_CALLBACK (pk_backend_dbus_category_cb), backend_dbus);
 	dbus_g_proxy_disconnect_signal (proxy, "DistroUpgrade",
 					G_CALLBACK (pk_backend_dbus_distro_upgrade_cb), backend_dbus);
 	return TRUE;
@@ -497,6 +506,9 @@ pk_backend_dbus_set_name (PkBackendDbus *backend_dbus, const gchar *service)
 				 G_TYPE_STRING, G_TYPE_STRING, G_TYPE_UINT64, G_TYPE_INVALID);
 	dbus_g_proxy_add_signal (proxy, "Files",
 				 G_TYPE_STRING, G_TYPE_STRING, G_TYPE_INVALID);
+	dbus_g_proxy_add_signal (proxy, "Category",
+				 G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING,
+				 G_TYPE_STRING, G_TYPE_STRING, G_TYPE_INVALID);
 	dbus_g_proxy_add_signal (proxy, "UpdateDetail",
 				 G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING,
 				 G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING,
@@ -538,6 +550,8 @@ pk_backend_dbus_set_name (PkBackendDbus *backend_dbus, const gchar *service)
 				     G_CALLBACK (pk_backend_dbus_details_cb), backend_dbus, NULL);
 	dbus_g_proxy_connect_signal (proxy, "Files",
 				     G_CALLBACK (pk_backend_dbus_files_cb), backend_dbus, NULL);
+	dbus_g_proxy_connect_signal (proxy, "Category",
+				     G_CALLBACK (pk_backend_dbus_category_cb), backend_dbus, NULL);
 	dbus_g_proxy_connect_signal (proxy, "UpdateDetail",
 				     G_CALLBACK (pk_backend_dbus_update_detail_cb), backend_dbus, NULL);
 	dbus_g_proxy_connect_signal (proxy, "Finished",
@@ -770,6 +784,33 @@ pk_backend_dbus_update_system (PkBackendDbus *backend_dbus)
 	return ret;
 }
 
+/**
+ * pk_backend_dbus_get_categories:
+ **/
+gboolean
+pk_backend_dbus_get_categories (PkBackendDbus *backend_dbus)
+{
+	gboolean ret;
+	GError *error = NULL;
+
+	g_return_val_if_fail (PK_IS_BACKEND_DBUS (backend_dbus), FALSE);
+	g_return_val_if_fail (backend_dbus->priv->proxy != NULL, FALSE);
+
+	/* new sync method call */
+	pk_backend_dbus_time_reset (backend_dbus);
+	ret = dbus_g_proxy_call (backend_dbus->priv->proxy, "GetCategories", &error,
+				 G_TYPE_INVALID, G_TYPE_INVALID);
+	if (error != NULL) {
+		egg_warning ("%s", error->message);
+		pk_backend_error_code (backend_dbus->priv->backend, PK_ERROR_ENUM_INTERNAL_ERROR, error->message);
+		pk_backend_finished (backend_dbus->priv->backend);
+		g_error_free (error);
+	}
+	if (ret)
+		pk_backend_dbus_time_check (backend_dbus);
+	return ret;
+}
+
 /**
  * pk_backend_dbus_repo_enable:
  **/
@@ -1364,36 +1405,6 @@ pk_backend_dbus_install_files (PkBackendDbus *backend_dbus, gboolean trusted, gc
 	return ret;
 }
 
-/**
- * pk_backend_dbus_service_pack:
- **/
-gboolean
-pk_backend_dbus_service_pack (PkBackendDbus *backend_dbus, const gchar *location, gboolean enabled)
-{
-	gboolean ret;
-	GError *error = NULL;
-
-	g_return_val_if_fail (PK_IS_BACKEND_DBUS (backend_dbus), FALSE);
-	g_return_val_if_fail (backend_dbus->priv->proxy != NULL, FALSE);
-	g_return_val_if_fail (location != NULL, FALSE);
-
-	/* new sync method call */
-	pk_backend_dbus_time_reset (backend_dbus);
-	ret = dbus_g_proxy_call (backend_dbus->priv->proxy, "ServicePack", &error,
-				 G_TYPE_STRING, location,
-				 G_TYPE_BOOLEAN, enabled,
-				 G_TYPE_INVALID, G_TYPE_INVALID);
-	if (error != NULL) {
-		egg_warning ("%s", error->message);
-		pk_backend_error_code (backend_dbus->priv->backend, PK_ERROR_ENUM_INTERNAL_ERROR, error->message);
-		pk_backend_finished (backend_dbus->priv->backend);
-		g_error_free (error);
-	}
-	if (ret)
-		pk_backend_dbus_time_check (backend_dbus);
-	return ret;
-}
-
 /**
  * pk_backend_dbus_what_provides:
  **/
@@ -1538,6 +1549,10 @@ pk_backend_dbus_init (PkBackendDbus *backend_dbus)
 	dbus_g_object_register_marshaller (pk_marshal_VOID__STRING_STRING,
 					   G_TYPE_NONE, G_TYPE_STRING,
 					   G_TYPE_STRING, G_TYPE_INVALID);
+	/* Category */
+	dbus_g_object_register_marshaller (pk_marshal_VOID__STRING_STRING,
+					   G_TYPE_NONE, G_TYPE_STRING, G_TYPE_STRING,
+					   G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_INVALID);
 
 	/* Repo Signature Required */
 	dbus_g_object_register_marshaller (pk_marshal_VOID__STRING_STRING_STRING_STRING_STRING_STRING_STRING_UINT,
@@ -1564,10 +1579,6 @@ pk_backend_dbus_init (PkBackendDbus *backend_dbus)
 					   G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING,
 					   G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING,
 					   G_TYPE_STRING, G_TYPE_STRING, G_TYPE_INVALID);
-	/* Transaction */
-	dbus_g_object_register_marshaller (pk_marshal_VOID__STRING_STRING_BOOL_STRING_UINT_STRING,
-					   G_TYPE_NONE, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_BOOLEAN,
-					   G_TYPE_STRING, G_TYPE_UINT, G_TYPE_STRING, G_TYPE_INVALID);
 
 	dbus_g_object_register_marshaller (g_cclosure_marshal_VOID__STRING, G_TYPE_NONE, G_TYPE_STRING, G_TYPE_INVALID);
 }
