@@ -37,13 +37,8 @@
 
 #include <glib/gi18n.h>
 #include <glib/gprintf.h>
-
 #include <gmodule.h>
-
-#include <pk-common.h>
-#include <pk-package-id.h>
-#include <pk-enum.h>
-#include <pk-network.h>
+#include <packagekit-glib/packagekit.h>
 
 #include "egg-debug.h"
 #include "egg-string.h"
@@ -68,10 +63,34 @@ struct PkBackendSpawnPrivate
 	guint			 backend_finished_id;
 	PkConf			*conf;
 	gboolean		 finished;
+	PkBackendSpawnFilterFunc stdout_func;
+	PkBackendSpawnFilterFunc stderr_func;
 };
 
 G_DEFINE_TYPE (PkBackendSpawn, pk_backend_spawn, G_TYPE_OBJECT)
 
+/**
+ * pk_backend_spawn_set_filter_stdout:
+ **/
+gboolean
+pk_backend_spawn_set_filter_stdout (PkBackendSpawn *backend_spawn, PkBackendSpawnFilterFunc func)
+{
+	g_return_val_if_fail (PK_IS_BACKEND_SPAWN (backend_spawn), FALSE);
+	backend_spawn->priv->stdout_func = func;
+	return TRUE;
+}
+
+/**
+ * pk_backend_spawn_set_filter_stderr:
+ **/
+gboolean
+pk_backend_spawn_set_filter_stderr (PkBackendSpawn *backend_spawn, PkBackendSpawnFilterFunc func)
+{
+	g_return_val_if_fail (PK_IS_BACKEND_SPAWN (backend_spawn), FALSE);
+	backend_spawn->priv->stderr_func = func;
+	return TRUE;
+}
+
 /**
  * pk_backend_spawn_parse_stdout:
  *
@@ -384,6 +403,40 @@ pk_backend_spawn_parse_stdout (PkBackendSpawn *backend_spawn, const gchar *line)
 
 		ret = pk_backend_distro_upgrade (backend_spawn->priv->backend, distro_upgrade_enum, sections[2], sections[3]);
 		goto out;
+	} else if (egg_strequal (command, "category")) {
+
+		if (size != 6) {
+			egg_warning ("invalid command '%s'", command);
+			ret = FALSE;
+			goto out;
+		}
+		if (egg_strequal (sections[1], sections[2])) {
+			pk_backend_message (backend_spawn->priv->backend, PK_MESSAGE_ENUM_BACKEND_ERROR, "cat_id cannot be the same as parent_id");
+			ret = FALSE;
+			goto out;
+		}
+		if (egg_strzero (sections[2])) {
+			pk_backend_message (backend_spawn->priv->backend, PK_MESSAGE_ENUM_BACKEND_ERROR, "cat_id cannot not blank");
+			ret = FALSE;
+			goto out;
+		}
+		if (egg_strzero (sections[3])) {
+			pk_backend_message (backend_spawn->priv->backend, PK_MESSAGE_ENUM_BACKEND_ERROR, "name cannot not blank");
+			ret = FALSE;
+			goto out;
+		}
+		if (egg_strzero (sections[5])) {
+			pk_backend_message (backend_spawn->priv->backend, PK_MESSAGE_ENUM_BACKEND_ERROR, "icon cannot not blank");
+			ret = FALSE;
+			goto out;
+		}
+		if (g_str_has_prefix (sections[5], "/")) {
+			pk_backend_message (backend_spawn->priv->backend, PK_MESSAGE_ENUM_BACKEND_ERROR, "icon '%s' should be a named icon, not a path", sections[5]);
+			ret = FALSE;
+			goto out;
+		}
+		ret = pk_backend_category (backend_spawn->priv->backend, sections[1], sections[2], sections[3], sections[4], sections[5]);
+		goto out;
 	} else {
 		egg_warning ("invalid command '%s'", command);
 	}
@@ -427,11 +480,39 @@ pk_backend_spawn_stdout_cb (PkBackendSpawn *spawn, const gchar *line, PkBackendS
 	gboolean ret;
 	g_return_if_fail (PK_IS_BACKEND_SPAWN (backend_spawn));
 
+	/* do we ignore with a filter func ? */
+	if (backend_spawn->priv->stdout_func != NULL) {
+		ret = backend_spawn->priv->stdout_func (backend_spawn->priv->backend, line);
+		if (!ret)
+			return;
+	}
+
 	ret = pk_backend_spawn_parse_stdout (backend_spawn, line);
 	if (!ret)
 		egg_debug ("failed to parse '%s'", line);
 }
 
+/**
+ * pk_backend_spawn_stderr_cb:
+ **/
+static void
+pk_backend_spawn_stderr_cb (PkBackendSpawn *spawn, const gchar *line, PkBackendSpawn *backend_spawn)
+{
+	gboolean ret;
+	g_return_if_fail (PK_IS_BACKEND_SPAWN (backend_spawn));
+
+	/* do we ignore with a filter func ? */
+	if (backend_spawn->priv->stderr_func != NULL) {
+		ret = backend_spawn->priv->stderr_func (backend_spawn->priv->backend, line);
+		if (!ret)
+			return;
+	}
+
+	/* send warning up to session, this is never going to be pretty... */
+	egg_warning ("STDERR: %s", line);
+	pk_backend_message (backend_spawn->priv->backend, PK_MESSAGE_ENUM_BACKEND_ERROR, "%s", line);
+}
+
 /**
  * pk_backend_spawn_get_envp:
  *
@@ -688,6 +769,8 @@ pk_backend_spawn_init (PkBackendSpawn *backend_spawn)
 	backend_spawn->priv = PK_BACKEND_SPAWN_GET_PRIVATE (backend_spawn);
 	backend_spawn->priv->kill_id = 0;
 	backend_spawn->priv->name = NULL;
+	backend_spawn->priv->stdout_func = NULL;
+	backend_spawn->priv->stderr_func = NULL;
 	backend_spawn->priv->finished = FALSE;
 	backend_spawn->priv->conf = pk_conf_new ();
 	backend_spawn->priv->backend = pk_backend_new ();
@@ -699,6 +782,8 @@ pk_backend_spawn_init (PkBackendSpawn *backend_spawn)
 			  G_CALLBACK (pk_backend_spawn_exit_cb), backend_spawn);
 	g_signal_connect (backend_spawn->priv->spawn, "stdout",
 			  G_CALLBACK (pk_backend_spawn_stdout_cb), backend_spawn);
+	g_signal_connect (backend_spawn->priv->spawn, "stderr",
+			  G_CALLBACK (pk_backend_spawn_stderr_cb), backend_spawn);
 }
 
 /**
