@@ -31,21 +31,18 @@
 #include <glib.h>
 #include <gmodule.h>
 #include <glib/gprintf.h>
-#include <pk-network.h>
+#include <packagekit-glib/packagekit.h>
 
 #include "egg-debug.h"
 #include "egg-string.h"
 
-#include "pk-package-obj.h"
-#include "pk-common.h"
+#include "pk-network.h"
 #include "pk-marshal.h"
 #include "pk-backend-internal.h"
 #include "pk-backend.h"
 #include "pk-store.h"
 #include "pk-time.h"
 #include "pk-file-monitor.h"
-#include "pk-update-detail-obj.h"
-#include "pk-details-obj.h"
 
 #define PK_BACKEND_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PK_TYPE_BACKEND, PkBackendPrivate))
 
@@ -131,6 +128,7 @@ enum {
 	PK_BACKEND_FINISHED,
 	PK_BACKEND_ALLOW_CANCEL,
 	PK_BACKEND_REPO_DETAIL,
+	PK_BACKEND_CATEGORY,
 	PK_BACKEND_LAST_SIGNAL
 };
 
@@ -247,6 +245,8 @@ pk_backend_get_actions (PkBackend *backend)
 		pk_bitfield_add (roles, PK_ROLE_ENUM_REPO_SET_DATA);
 	if (desc->get_distro_upgrades != NULL)
 		pk_bitfield_add (roles, PK_ROLE_ENUM_GET_DISTRO_UPGRADES);
+	if (desc->get_categories != NULL)
+		pk_bitfield_add (roles, PK_ROLE_ENUM_GET_CATEGORIES);
 	return roles;
 }
 
@@ -804,7 +804,6 @@ pk_backend_package (PkBackend *backend, PkInfoEnum info, const gchar *package_id
 	obj = pk_package_obj_new (info, id, summary_safe);
 	ret = pk_package_obj_equal (obj, backend->priv->last_package);
 	if (ret) {
-		pk_package_obj_free (obj);
 		egg_debug ("skipping duplicate %s", package_id);
 		return FALSE;
 	}
@@ -935,7 +934,7 @@ pk_backend_require_restart (PkBackend *backend, PkRestartEnum restart, const gch
 		return FALSE;
 	}
 
-	egg_debug ("emit require-restart %i, %s", restart, details);
+	egg_debug ("emit require-restart %s, %s", pk_restart_enum_to_text (restart), details);
 	g_signal_emit (backend, signals [PK_BACKEND_REQUIRE_RESTART], 0, restart, details);
 
 	return TRUE;
@@ -1212,6 +1211,34 @@ pk_backend_repo_detail (PkBackend *backend, const gchar *repo_id,
 	return TRUE;
 }
 
+/**
+ * pk_backend_category:
+ **/
+gboolean
+pk_backend_category (PkBackend *backend, const gchar *parent_id, const gchar *cat_id, const gchar *name, const gchar *summary, const gchar *icon)
+{
+	gchar *summary_safe;
+
+	g_return_val_if_fail (PK_IS_BACKEND (backend), FALSE);
+	g_return_val_if_fail (cat_id != NULL, FALSE);
+	g_return_val_if_fail (backend->priv->locked != FALSE, FALSE);
+
+	/* have we already set an error? */
+	if (backend->priv->set_error) {
+		egg_warning ("already set error, cannot process: category %s", cat_id);
+		return FALSE;
+	}
+
+	/* replace unsafe chars */
+	summary_safe = pk_strsafe (summary);
+
+	egg_debug ("emit category %s, %s, %s, %s, %s", parent_id, cat_id, name, summary_safe, icon);
+	g_signal_emit (backend, signals [PK_BACKEND_CATEGORY], 0, parent_id, cat_id, name, summary, icon);
+	g_free (summary_safe);
+	return TRUE;
+
+}
+
 /**
  * pk_backend_error_timeout_delay_cb:
  *
@@ -1305,6 +1332,12 @@ pk_backend_set_allow_cancel (PkBackend *backend, gboolean allow_cancel)
 		return FALSE;
 	}
 
+	/* same as last state? */
+	if (backend->priv->allow_cancel == allow_cancel) {
+		egg_debug ("ignoring same allow-cancel state");
+		return TRUE;
+	}
+
 	/* can we do the action? */
 	if (backend->desc->cancel != NULL) {
 		backend->priv->allow_cancel = allow_cancel;
@@ -1440,8 +1473,7 @@ pk_backend_finished (PkBackend *backend)
 
 	/* check we have not already finished */
 	if (backend->priv->finished) {
-		pk_backend_message (backend, PK_MESSAGE_ENUM_BACKEND_ERROR,
-				    "%s cannot request Finished more than once!", role_text);
+		egg_warning ("already finished");
 		return FALSE;
 	}
 
@@ -1777,6 +1809,11 @@ pk_backend_class_init (PkBackendClass *klass)
 			      G_TYPE_FROM_CLASS (object_class), G_SIGNAL_RUN_LAST,
 			      0, NULL, NULL, pk_marshal_VOID__STRING_STRING_BOOL,
 			      G_TYPE_NONE, 3, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_BOOLEAN);
+	signals [PK_BACKEND_CATEGORY] =
+		g_signal_new ("category",
+			      G_TYPE_FROM_CLASS (object_class), G_SIGNAL_RUN_LAST,
+			      0, NULL, NULL, pk_marshal_VOID__STRING_STRING_STRING_STRING_STRING,
+			      G_TYPE_NONE, 5, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING);
 	g_type_class_add_private (klass, sizeof (PkBackendPrivate));
 }
 
