@@ -26,6 +26,7 @@
 #include <signal.h>
 #include <unistd.h>
 #include <stdlib.h>
+#include <locale.h>
 #include <glib.h>
 #include <glib/gi18n.h>
 #include <dbus/dbus-glib.h>
@@ -36,13 +37,13 @@
 
 #include "pk-conf.h"
 #include "pk-engine.h"
+#include "pk-syslog.h"
 #include "pk-transaction.h"
 #include "pk-backend-internal.h"
-#include "pk-interface.h"
+#include "org.freedesktop.PackageKit.h"
 
 static guint exit_idle_time;
-static PkEngine *engine = NULL;
-static PkBackend *backend = NULL;
+static GMainLoop *loop;
 
 /**
  * pk_object_register:
@@ -81,12 +82,13 @@ pk_object_register (DBusGConnection *connection, GObject *object, GError **error
 	if (!ret) {
 		egg_warning ("RequestName failed!");
 		g_clear_error (error);
-		message = g_strdup_printf ("%s\n%s\n* %s\n* %s\n",
+		message = g_strdup_printf ("%s\n%s\n* %s\n* %s '%s'\n",
 					   _("Startup failed due to security policies on this machine."),
 					   _("This can happen for two reasons:"),
 					   _("The correct user is not launching the executable (usually root)"),
 					   _("The org.freedesktop.PackageKit.conf file is not "
-					     "installed in the system /etc/dbus-1/system.d directory"));
+					     "installed in the system directory:"),
+					     "/etc/dbus-1/system.d");
 		g_set_error (error, PK_ENGINE_ERROR, PK_ENGINE_ERROR_DENIED, "%s", message);
 		g_free (message);
 		return FALSE;
@@ -133,7 +135,8 @@ pk_main_timeout_check_cb (PkEngine *engine)
 	egg_debug ("idle is %i", idle);
 	if (idle > exit_idle_time) {
 		egg_warning ("exit!!");
-		exit (0);
+		g_main_loop_quit (loop);
+		return FALSE;
 	}
 	return TRUE;
 }
@@ -149,16 +152,8 @@ pk_main_sigint_handler (int sig)
 	/* restore default ASAP, as the finalisers might hang */
 	signal (SIGINT, SIG_DFL);
 
-	/* cleanup */
-	g_object_unref (backend);
-	g_object_unref (engine);
-
-	/* give the backend a sporting chance */
-	g_usleep (500*1000);
-
-	/* kill ourselves */
-	egg_debug ("Retrying SIGINT");
-	kill (getpid (), SIGINT);
+	/* exit loop */
+	g_main_loop_quit (loop);
 }
 
 /**
@@ -167,7 +162,6 @@ pk_main_sigint_handler (int sig)
 int
 main (int argc, char *argv[])
 {
-	GMainLoop *loop;
 	DBusGConnection *system_connection;
 	EggDbusMonitor *monitor;
 	gboolean ret;
@@ -179,7 +173,10 @@ main (int argc, char *argv[])
 	gboolean immediate_exit = FALSE;
 	gboolean do_logging = FALSE;
 	gchar *backend_name = NULL;
+	PkEngine *engine = NULL;
+	PkBackend *backend = NULL;
 	PkConf *conf = NULL;
+	PkSyslog *syslog = NULL;
 	GError *error = NULL;
 	GOptionContext *context;
 	const gchar *env_pk_verbose;
@@ -204,9 +201,13 @@ main (int argc, char *argv[])
 		{ NULL}
 	};
 
-	if (! g_thread_supported ()) {
+	setlocale (LC_ALL, "");
+	bindtextdomain (GETTEXT_PACKAGE, PACKAGE_LOCALE_DIR);
+	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+	textdomain (GETTEXT_PACKAGE);
+
+	if (! g_thread_supported ())
 		g_thread_init (NULL);
-	}
 	dbus_g_thread_init ();
 	g_type_init ();
 
@@ -264,6 +265,10 @@ main (int argc, char *argv[])
 	/* get values from the config file */
 	conf = pk_conf_new ();
 
+	/* log the startup */
+	syslog = pk_syslog_new ();
+	pk_syslog_add (syslog, PK_SYSLOG_TYPE_INFO, "daemon start");
+
 	/* do we log? */
 	do_logging = pk_conf_get_bool (conf, "TransactionLogging");
 	egg_debug ("Log all transactions: %i", do_logging);
@@ -284,9 +289,8 @@ main (int argc, char *argv[])
 	g_free (backend_name);
 
 	/* all okay? */
-	if (!ret) {
+	if (!ret)
 		egg_error ("cannot continue, backend invalid");
-	}
 
 	/* create a new engine object */
 	engine = pk_engine_new ();
@@ -316,6 +320,10 @@ main (int argc, char *argv[])
 	g_main_loop_unref (loop);
 
 out:
+	/* log the shutdown */
+	pk_syslog_add (syslog, PK_SYSLOG_TYPE_INFO, "daemon quit");
+
+	g_object_unref (syslog);
 	g_object_unref (conf);
 	g_object_unref (engine);
 	g_object_unref (backend);
