@@ -1364,28 +1364,30 @@ pk_marshal_VOID__STRING_STRING_UINT_UINT_UINT (GClosure     *closure,
             data2);
 }
 
-/* VOID:STRING,STRING,BOOL,UINT,UINT,STRING (pk-marshal.list:33) */
+/* VOID:STRING,STRING,BOOL,UINT,UINT,STRING,UINT,STRING (pk-marshal.list:33) */
 void
-pk_marshal_VOID__STRING_STRING_BOOLEAN_UINT_UINT_STRING (GClosure     *closure,
-                                                         GValue       *return_value G_GNUC_UNUSED,
-                                                         guint         n_param_values,
-                                                         const GValue *param_values,
-                                                         gpointer      invocation_hint G_GNUC_UNUSED,
-                                                         gpointer      marshal_data)
+pk_marshal_VOID__STRING_STRING_BOOLEAN_UINT_UINT_STRING_UINT_STRING (GClosure     *closure,
+                                                                     GValue       *return_value G_GNUC_UNUSED,
+                                                                     guint         n_param_values,
+                                                                     const GValue *param_values,
+                                                                     gpointer      invocation_hint G_GNUC_UNUSED,
+                                                                     gpointer      marshal_data)
 {
-  typedef void (*GMarshalFunc_VOID__STRING_STRING_BOOLEAN_UINT_UINT_STRING) (gpointer     data1,
-                                                                             gpointer     arg_1,
-                                                                             gpointer     arg_2,
-                                                                             gboolean     arg_3,
-                                                                             guint        arg_4,
-                                                                             guint        arg_5,
-                                                                             gpointer     arg_6,
-                                                                             gpointer     data2);
-  register GMarshalFunc_VOID__STRING_STRING_BOOLEAN_UINT_UINT_STRING callback;
+  typedef void (*GMarshalFunc_VOID__STRING_STRING_BOOLEAN_UINT_UINT_STRING_UINT_STRING) (gpointer     data1,
+                                                                                         gpointer     arg_1,
+                                                                                         gpointer     arg_2,
+                                                                                         gboolean     arg_3,
+                                                                                         guint        arg_4,
+                                                                                         guint        arg_5,
+                                                                                         gpointer     arg_6,
+                                                                                         guint        arg_7,
+                                                                                         gpointer     arg_8,
+                                                                                         gpointer     data2);
+  register GMarshalFunc_VOID__STRING_STRING_BOOLEAN_UINT_UINT_STRING_UINT_STRING callback;
   register GCClosure *cc = (GCClosure*) closure;
   register gpointer data1, data2;
 
-  g_return_if_fail (n_param_values == 7);
+  g_return_if_fail (n_param_values == 9);
 
   if (G_CCLOSURE_SWAP_DATA (closure))
     {
@@ -1397,7 +1399,7 @@ pk_marshal_VOID__STRING_STRING_BOOLEAN_UINT_UINT_STRING (GClosure     *closure,
       data1 = g_value_peek_pointer (param_values + 0);
       data2 = closure->data;
     }
-  callback = (GMarshalFunc_VOID__STRING_STRING_BOOLEAN_UINT_UINT_STRING) (marshal_data ? marshal_data : cc->callback);
+  callback = (GMarshalFunc_VOID__STRING_STRING_BOOLEAN_UINT_UINT_STRING_UINT_STRING) (marshal_data ? marshal_data : cc->callback);
 
   callback (data1,
             g_marshal_value_peek_string (param_values + 1),
@@ -1406,32 +1408,36 @@ pk_marshal_VOID__STRING_STRING_BOOLEAN_UINT_UINT_STRING (GClosure     *closure,
             g_marshal_value_peek_uint (param_values + 4),
             g_marshal_value_peek_uint (param_values + 5),
             g_marshal_value_peek_string (param_values + 6),
+            g_marshal_value_peek_uint (param_values + 7),
+            g_marshal_value_peek_string (param_values + 8),
             data2);
 }
 
-/* VOID:STRING,STRING,STRING,BOOL,STRING,UINT,STRING (pk-marshal.list:34) */
+/* VOID:STRING,STRING,STRING,BOOL,STRING,UINT,STRING,UINT,STRING (pk-marshal.list:34) */
 void
-pk_marshal_VOID__STRING_STRING_STRING_BOOLEAN_STRING_UINT_STRING (GClosure     *closure,
-                                                                  GValue       *return_value G_GNUC_UNUSED,
-                                                                  guint         n_param_values,
-                                                                  const GValue *param_values,
-                                                                  gpointer      invocation_hint G_GNUC_UNUSED,
-                                                                  gpointer      marshal_data)
+pk_marshal_VOID__STRING_STRING_STRING_BOOLEAN_STRING_UINT_STRING_UINT_STRING (GClosure     *closure,
+                                                                              GValue       *return_value G_GNUC_UNUSED,
+                                                                              guint         n_param_values,
+                                                                              const GValue *param_values,
+                                                                              gpointer      invocation_hint G_GNUC_UNUSED,
+                                                                              gpointer      marshal_data)
 {
-  typedef void (*GMarshalFunc_VOID__STRING_STRING_STRING_BOOLEAN_STRING_UINT_STRING) (gpointer     data1,
-                                                                                      gpointer     arg_1,
-                                                                                      gpointer     arg_2,
-                                                                                      gpointer     arg_3,
-                                                                                      gboolean     arg_4,
-                                                                                      gpointer     arg_5,
-                                                                                      guint        arg_6,
-                                                                                      gpointer     arg_7,
-                                                                                      gpointer     data2);
-  register GMarshalFunc_VOID__STRING_STRING_STRING_BOOLEAN_STRING_UINT_STRING callback;
+  typedef void (*GMarshalFunc_VOID__STRING_STRING_STRING_BOOLEAN_STRING_UINT_STRING_UINT_STRING) (gpointer     data1,
+                                                                                                  gpointer     arg_1,
+                                                                                                  gpointer     arg_2,
+                                                                                                  gpointer     arg_3,
+                                                                                                  gboolean     arg_4,
+                                                                                                  gpointer     arg_5,
+                                                                                                  guint        arg_6,
+                                                                                                  gpointer     arg_7,
+                                                                                                  guint        arg_8,
+                                                                                                  gpointer     arg_9,
+                                                                                                  gpointer     data2);
+  register GMarshalFunc_VOID__STRING_STRING_STRING_BOOLEAN_STRING_UINT_STRING_UINT_STRING callback;
   register GCClosure *cc = (GCClosure*) closure;
   register gpointer data1, data2;
 
-  g_return_if_fail (n_param_values == 8);
+  g_return_if_fail (n_param_values == 10);
 
   if (G_CCLOSURE_SWAP_DATA (closure))
     {
@@ -1443,7 +1449,7 @@ pk_marshal_VOID__STRING_STRING_STRING_BOOLEAN_STRING_UINT_STRING (GClosure     *
       data1 = g_value_peek_pointer (param_values + 0);
       data2 = closure->data;
     }
-  callback = (GMarshalFunc_VOID__STRING_STRING_STRING_BOOLEAN_STRING_UINT_STRING) (marshal_data ? marshal_data : cc->callback);
+  callback = (GMarshalFunc_VOID__STRING_STRING_STRING_BOOLEAN_STRING_UINT_STRING_UINT_STRING) (marshal_data ? marshal_data : cc->callback);
 
   callback (data1,
             g_marshal_value_peek_string (param_values + 1),
@@ -1453,31 +1459,35 @@ pk_marshal_VOID__STRING_STRING_STRING_BOOLEAN_STRING_UINT_STRING (GClosure     *
             g_marshal_value_peek_string (param_values + 5),
             g_marshal_value_peek_uint (param_values + 6),
             g_marshal_value_peek_string (param_values + 7),
+            g_marshal_value_peek_uint (param_values + 8),
+            g_marshal_value_peek_string (param_values + 9),
             data2);
 }
 
-/* VOID:STRING,STRING,BOOL,STRING,UINT,STRING (pk-marshal.list:35) */
+/* VOID:STRING,STRING,BOOL,STRING,UINT,STRING,UINT,STRING (pk-marshal.list:35) */
 void
-pk_marshal_VOID__STRING_STRING_BOOLEAN_STRING_UINT_STRING (GClosure     *closure,
-                                                           GValue       *return_value G_GNUC_UNUSED,
-                                                           guint         n_param_values,
-                                                           const GValue *param_values,
-                                                           gpointer      invocation_hint G_GNUC_UNUSED,
-                                                           gpointer      marshal_data)
+pk_marshal_VOID__STRING_STRING_BOOLEAN_STRING_UINT_STRING_UINT_STRING (GClosure     *closure,
+                                                                       GValue       *return_value G_GNUC_UNUSED,
+                                                                       guint         n_param_values,
+                                                                       const GValue *param_values,
+                                                                       gpointer      invocation_hint G_GNUC_UNUSED,
+                                                                       gpointer      marshal_data)
 {
-  typedef void (*GMarshalFunc_VOID__STRING_STRING_BOOLEAN_STRING_UINT_STRING) (gpointer     data1,
-                                                                               gpointer     arg_1,
-                                                                               gpointer     arg_2,
-                                                                               gboolean     arg_3,
-                                                                               gpointer     arg_4,
-                                                                               guint        arg_5,
-                                                                               gpointer     arg_6,
-                                                                               gpointer     data2);
-  register GMarshalFunc_VOID__STRING_STRING_BOOLEAN_STRING_UINT_STRING callback;
+  typedef void (*GMarshalFunc_VOID__STRING_STRING_BOOLEAN_STRING_UINT_STRING_UINT_STRING) (gpointer     data1,
+                                                                                           gpointer     arg_1,
+                                                                                           gpointer     arg_2,
+                                                                                           gboolean     arg_3,
+                                                                                           gpointer     arg_4,
+                                                                                           guint        arg_5,
+                                                                                           gpointer     arg_6,
+                                                                                           guint        arg_7,
+                                                                                           gpointer     arg_8,
+                                                                                           gpointer     data2);
+  register GMarshalFunc_VOID__STRING_STRING_BOOLEAN_STRING_UINT_STRING_UINT_STRING callback;
   register GCClosure *cc = (GCClosure*) closure;
   register gpointer data1, data2;
 
-  g_return_if_fail (n_param_values == 7);
+  g_return_if_fail (n_param_values == 9);
 
   if (G_CCLOSURE_SWAP_DATA (closure))
     {
@@ -1489,7 +1499,7 @@ pk_marshal_VOID__STRING_STRING_BOOLEAN_STRING_UINT_STRING (GClosure     *closure
       data1 = g_value_peek_pointer (param_values + 0);
       data2 = closure->data;
     }
-  callback = (GMarshalFunc_VOID__STRING_STRING_BOOLEAN_STRING_UINT_STRING) (marshal_data ? marshal_data : cc->callback);
+  callback = (GMarshalFunc_VOID__STRING_STRING_BOOLEAN_STRING_UINT_STRING_UINT_STRING) (marshal_data ? marshal_data : cc->callback);
 
   callback (data1,
             g_marshal_value_peek_string (param_values + 1),
@@ -1498,6 +1508,8 @@ pk_marshal_VOID__STRING_STRING_BOOLEAN_STRING_UINT_STRING (GClosure     *closure
             g_marshal_value_peek_string (param_values + 4),
             g_marshal_value_peek_uint (param_values + 5),
             g_marshal_value_peek_string (param_values + 6),
+            g_marshal_value_peek_uint (param_values + 7),
+            g_marshal_value_peek_string (param_values + 8),
             data2);
 }
 
