@@ -254,32 +254,32 @@ extern void pk_marshal_VOID__STRING_STRING_UINT_UINT_UINT (GClosure     *closure
                                                            gpointer      invocation_hint,
                                                            gpointer      marshal_data);
 
-/* VOID:STRING,STRING,BOOL,UINT,UINT,STRING (pk-marshal.list:33) */
-extern void pk_marshal_VOID__STRING_STRING_BOOLEAN_UINT_UINT_STRING (GClosure     *closure,
-                                                                     GValue       *return_value,
-                                                                     guint         n_param_values,
-                                                                     const GValue *param_values,
-                                                                     gpointer      invocation_hint,
-                                                                     gpointer      marshal_data);
-#define pk_marshal_VOID__STRING_STRING_BOOL_UINT_UINT_STRING	pk_marshal_VOID__STRING_STRING_BOOLEAN_UINT_UINT_STRING
+/* VOID:STRING,STRING,BOOL,UINT,UINT,STRING,UINT,STRING (pk-marshal.list:33) */
+extern void pk_marshal_VOID__STRING_STRING_BOOLEAN_UINT_UINT_STRING_UINT_STRING (GClosure     *closure,
+                                                                                 GValue       *return_value,
+                                                                                 guint         n_param_values,
+                                                                                 const GValue *param_values,
+                                                                                 gpointer      invocation_hint,
+                                                                                 gpointer      marshal_data);
+#define pk_marshal_VOID__STRING_STRING_BOOL_UINT_UINT_STRING_UINT_STRING	pk_marshal_VOID__STRING_STRING_BOOLEAN_UINT_UINT_STRING_UINT_STRING
 
-/* VOID:STRING,STRING,STRING,BOOL,STRING,UINT,STRING (pk-marshal.list:34) */
-extern void pk_marshal_VOID__STRING_STRING_STRING_BOOLEAN_STRING_UINT_STRING (GClosure     *closure,
-                                                                              GValue       *return_value,
-                                                                              guint         n_param_values,
-                                                                              const GValue *param_values,
-                                                                              gpointer      invocation_hint,
-                                                                              gpointer      marshal_data);
-#define pk_marshal_VOID__STRING_STRING_STRING_BOOL_STRING_UINT_STRING	pk_marshal_VOID__STRING_STRING_STRING_BOOLEAN_STRING_UINT_STRING
+/* VOID:STRING,STRING,STRING,BOOL,STRING,UINT,STRING,UINT,STRING (pk-marshal.list:34) */
+extern void pk_marshal_VOID__STRING_STRING_STRING_BOOLEAN_STRING_UINT_STRING_UINT_STRING (GClosure     *closure,
+                                                                                          GValue       *return_value,
+                                                                                          guint         n_param_values,
+                                                                                          const GValue *param_values,
+                                                                                          gpointer      invocation_hint,
+                                                                                          gpointer      marshal_data);
+#define pk_marshal_VOID__STRING_STRING_STRING_BOOL_STRING_UINT_STRING_UINT_STRING	pk_marshal_VOID__STRING_STRING_STRING_BOOLEAN_STRING_UINT_STRING_UINT_STRING
 
-/* VOID:STRING,STRING,BOOL,STRING,UINT,STRING (pk-marshal.list:35) */
-extern void pk_marshal_VOID__STRING_STRING_BOOLEAN_STRING_UINT_STRING (GClosure     *closure,
-                                                                       GValue       *return_value,
-                                                                       guint         n_param_values,
-                                                                       const GValue *param_values,
-                                                                       gpointer      invocation_hint,
-                                                                       gpointer      marshal_data);
-#define pk_marshal_VOID__STRING_STRING_BOOL_STRING_UINT_STRING	pk_marshal_VOID__STRING_STRING_BOOLEAN_STRING_UINT_STRING
+/* VOID:STRING,STRING,BOOL,STRING,UINT,STRING,UINT,STRING (pk-marshal.list:35) */
+extern void pk_marshal_VOID__STRING_STRING_BOOLEAN_STRING_UINT_STRING_UINT_STRING (GClosure     *closure,
+                                                                                   GValue       *return_value,
+                                                                                   guint         n_param_values,
+                                                                                   const GValue *param_values,
+                                                                                   gpointer      invocation_hint,
+                                                                                   gpointer      marshal_data);
+#define pk_marshal_VOID__STRING_STRING_BOOL_STRING_UINT_STRING_UINT_STRING	pk_marshal_VOID__STRING_STRING_BOOLEAN_STRING_UINT_STRING_UINT_STRING
 
 /* VOID:POINTER,UINT,STRING (pk-marshal.list:36) */
 extern void pk_marshal_VOID__POINTER_UINT_STRING (GClosure     *closure,
