@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
- * Copyright (C) 2007 Richard Hughes <richard@hughsie.com>
+ * Copyright (C) 2007-2008 Richard Hughes <richard@hughsie.com>
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -35,14 +35,13 @@
 
 #include <polkit/polkit.h>
 #include <polkit-dbus/polkit-dbus.h>
-
-#include <pk-enum.h>
-#include <pk-common.h>
+#include <packagekit-glib/packagekit.h>
 
 #include "egg-debug.h"
 #include "egg-string.h"
 
 #include "pk-security.h"
+#include "pk-syslog.h"
 
 #define PK_SECURITY_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PK_TYPE_SECURITY, PkSecurityPrivate))
 
@@ -50,84 +49,101 @@ struct PkSecurityPrivate
 {
 	PolKitContext		*pk_context;
 	DBusConnection		*connection;
+	PkSyslog		*syslog;
 };
 
+typedef PolKitCaller PkSecurityCaller_;
+
 G_DEFINE_TYPE (PkSecurity, pk_security, G_TYPE_OBJECT)
 static gpointer pk_security_object = NULL;
 
 /**
- * pk_security_uid_from_dbus_sender:
+ * pk_security_caller_new_from_sender:
  **/
-gboolean
-pk_security_uid_from_dbus_sender (PkSecurity *security, const gchar *dbus_name, guint *uid)
+PkSecurityCaller *
+pk_security_caller_new_from_sender (PkSecurity *security, const gchar *sender)
 {
 	PolKitCaller *caller;
 	DBusError dbus_error;
-	polkit_bool_t retval;
-	gboolean ret = FALSE;
 
 	g_return_val_if_fail (PK_IS_SECURITY (security), FALSE);
 
 	/* get the PolKitCaller information */
 	dbus_error_init (&dbus_error);
-	caller = polkit_caller_new_from_dbus_name (security->priv->connection, dbus_name, &dbus_error);
+	caller = polkit_caller_new_from_dbus_name (security->priv->connection, sender, &dbus_error);
 	if (dbus_error_is_set (&dbus_error)) {
-		egg_warning ("failed to get caller %s: %s\n", dbus_error.name, dbus_error.message);
+		egg_debug ("failed to get caller %s: %s", dbus_error.name, dbus_error.message);
 		dbus_error_free (&dbus_error);
-		goto out;
 	}
 
-	/* get uid */
-	retval = polkit_caller_get_uid (caller, uid);
-	if (!retval) {
-		egg_warning ("failed to get UID");
-		goto out;
-	}
-	ret = TRUE;
-out:
-	polkit_caller_unref (caller);
-	return ret;
+	return (PkSecurityCaller*) caller;
 }
 
 /**
- * pk_security_can_do_action:
+ * pk_security_caller_unref:
  **/
-G_GNUC_WARN_UNUSED_RESULT static PolKitResult
-pk_security_can_do_action (PkSecurity *security, const gchar *dbus_sender, const gchar *action)
+void
+pk_security_caller_unref (PkSecurityCaller *caller)
 {
-	PolKitResult pk_result;
-	PolKitAction *pk_action;
-	PolKitCaller *pk_caller;
-	DBusError dbus_error;
+	if (caller != NULL)
+		polkit_caller_unref ((PolKitCaller *) caller);
+}
 
-	/* set action */
-	pk_action = polkit_action_new ();
-	if (pk_action == NULL) {
-		egg_warning ("error: polkit_action_new failed");
-		return POLKIT_RESULT_NO;
-	}
-	polkit_action_set_action_id (pk_action, action);
+/**
+ * pk_security_get_uid:
+ **/
+guint
+pk_security_get_uid (PkSecurity *security, PkSecurityCaller *caller)
+{
+	polkit_bool_t retval;
+	guint uid;
 
-	/* set caller */
-	egg_debug ("using caller %s for action %s", dbus_sender, action);
-	dbus_error_init (&dbus_error);
-	pk_caller = polkit_caller_new_from_dbus_name (security->priv->connection, dbus_sender, &dbus_error);
-	if (pk_caller == NULL) {
-		if (dbus_error_is_set (&dbus_error)) {
-			egg_warning ("error: polkit_caller_new_from_dbus_name(): %s: %s\n",
-				    dbus_error.name, dbus_error.message);
-			dbus_error_free (&dbus_error);
-		}
-		return POLKIT_RESULT_NO;
+	g_return_val_if_fail (PK_IS_SECURITY (security), -1);
+	g_return_val_if_fail (caller != NULL, -1);
+
+	/* get uid */
+	retval = polkit_caller_get_uid ((PolKitCaller *) caller, &uid);
+	if (!retval) {
+		egg_warning ("failed to get UID");
+		uid = PK_SECURITY_UID_INVALID;
 	}
 
-	pk_result = polkit_context_is_caller_authorized (security->priv->pk_context, pk_action, pk_caller, TRUE, NULL);
-	egg_debug ("PolicyKit result = '%s'", polkit_result_to_string_representation (pk_result));
+	return uid;
+}
 
-	polkit_action_unref (pk_action);
-	polkit_caller_unref (pk_caller);
+/**
+ * pk_security_get_cmdline:
+ **/
+gchar *
+pk_security_get_cmdline (PkSecurity *security, PkSecurityCaller *caller)
+{
+	gboolean ret;
+	gchar *filename = NULL;
+	gchar *cmdline = NULL;
+	GError *error = NULL;
+	polkit_bool_t retval;
+	pid_t pid;
 
-	return pk_result;
+	g_return_val_if_fail (PK_IS_SECURITY (security), NULL);
+	g_return_val_if_fail (caller != NULL, NULL);
+
+	/* get pid */
+	retval = polkit_caller_get_pid ((PolKitCaller *) caller, &pid);
+	if (!retval) {
+		egg_warning ("failed to get PID");
+		goto out;
+	}
+
+	/* get command line from proc */
+	filename = g_strdup_printf ("/proc/%i/cmdline", pid);
+	ret = g_file_get_contents (filename, &cmdline, NULL, &error);
+	if (!ret) {
+		egg_warning ("failed to get cmdline: %s", error->message);
+		g_error_free (error);
+	}
+out:
+	g_free (filename);
+	return cmdline;
 }
 
 /**
@@ -170,19 +186,19 @@ pk_security_role_to_action (PkSecurity *security, gboolean trusted, PkRoleEnum r
 
 /**
  * pk_security_action_is_allowed:
- *
- * Only valid from an async caller, which is fine, as we won't prompt the user
- * when not async.
  **/
 gboolean
-pk_security_action_is_allowed (PkSecurity *security, const gchar *dbus_sender,
-			       gboolean trusted, PkRoleEnum role, gchar **error_detail)
+pk_security_action_is_allowed (PkSecurity *security, PkSecurityCaller *caller, gboolean trusted, PkRoleEnum role, gchar **error_detail)
 {
-	PolKitResult pk_result;
+	gboolean ret = FALSE;
+	PolKitResult result;
 	const gchar *policy;
+	PolKitAction *action;
+	guint uid;
+	gchar *cmdline;
 
 	g_return_val_if_fail (PK_IS_SECURITY (security), FALSE);
-	g_return_val_if_fail (dbus_sender != NULL, FALSE);
+	g_return_val_if_fail (caller != NULL, FALSE);
 
 	/* map the roles to policykit rules */
 	policy = pk_security_role_to_action (security, trusted, role);
@@ -191,14 +207,39 @@ pk_security_action_is_allowed (PkSecurity *security, const gchar *dbus_sender,
 		return FALSE;
 	}
 
-	/* get the dbus sender */
-	pk_result = pk_security_can_do_action (security, dbus_sender, policy);
-	if (pk_result != POLKIT_RESULT_YES) {
-		if (error_detail != NULL)
-			*error_detail = g_strdup_printf ("%s %s", policy, polkit_result_to_string_representation (pk_result));
-		return FALSE;
+	/* set action */
+	action = polkit_action_new ();
+	if (action == NULL) {
+		egg_warning ("error: polkit_action_new failed");
+		goto out;
 	}
-	return TRUE;
+	polkit_action_set_action_id (action, policy);
+
+	/* set caller */
+	result = polkit_context_is_caller_authorized (security->priv->pk_context, action, (PolKitCaller *) caller, TRUE, NULL);
+	egg_debug ("PolicyKit result = '%s'", polkit_result_to_string_representation (result));
+	if (result != POLKIT_RESULT_YES) {
+		if (error_detail != NULL)
+			*error_detail = g_strdup_printf ("%s %s", policy, polkit_result_to_string_representation (result));
+		goto out;
+	}
+
+	/* yippee */
+	ret = TRUE;
+
+out:
+	/* log result */
+	uid = pk_security_get_uid (security, caller);
+	cmdline = pk_security_get_cmdline (security, caller);
+	if (ret)
+		pk_syslog_add (security->priv->syslog, PK_SYSLOG_TYPE_AUTH, "uid %i obtained %s auth (trusted:%i)", uid, policy, trusted);
+	else
+		pk_syslog_add (security->priv->syslog, PK_SYSLOG_TYPE_AUTH, "uid %i failed to obtain %s auth (trusted:%i)", uid, policy, trusted);
+	g_free (cmdline);
+
+	if (action != NULL)
+		polkit_action_unref (action);
+	return ret;
 }
 
 /**
@@ -213,6 +254,7 @@ pk_security_finalize (GObject *object)
 
 	/* unref PolicyKit */
 	polkit_context_unref (security->priv->pk_context);
+	g_object_unref (security->priv->syslog);
 
 	G_OBJECT_CLASS (pk_security_parent_class)->finalize (object);
 }
@@ -288,6 +330,9 @@ pk_security_init (PkSecurity *security)
 
 	egg_debug ("Using PolicyKit security framework");
 
+	/* use syslog */
+	security->priv->syslog = pk_syslog_new ();
+
 	/* get a connection to the bus */
 	dbus_error_init (&dbus_error);
 	security->priv->connection = dbus_bus_get (DBUS_BUS_SYSTEM, &dbus_error);
@@ -341,8 +386,6 @@ pk_security_test (EggTest *test)
 {
 	PkSecurity *security;
 	const gchar *action;
-	gboolean ret;
-	gchar *error;
 
 	if (!egg_test_start (test, "PkSecurity"))
 		return;
@@ -358,7 +401,7 @@ pk_security_test (EggTest *test)
 	egg_test_title (test, "map valid role to action");
 	action = pk_security_role_to_action (security, FALSE, PK_ROLE_ENUM_UPDATE_PACKAGES);
 	if (egg_strequal (action, "org.freedesktop.packagekit.system-update"))
-		egg_test_success (test, NULL, error);
+		egg_test_success (test, NULL);
 	else
 		egg_test_failed (test, "did not get correct action '%s'", action);
 
@@ -366,20 +409,10 @@ pk_security_test (EggTest *test)
 	egg_test_title (test, "map invalid role to action");
 	action = pk_security_role_to_action (security, FALSE, PK_ROLE_ENUM_SEARCH_NAME);
 	if (action == NULL)
-		egg_test_success (test, NULL, error);
+		egg_test_success (test, NULL);
 	else
 		egg_test_failed (test, "did not get correct action '%s'", action);
 
-	/************************************************************/
-	egg_test_title (test, "get the default backend");
-	error = NULL;
-	ret = pk_security_action_is_allowed (security, ":0", FALSE, PK_ROLE_ENUM_UPDATE_PACKAGES, &error);
-	if (ret == FALSE)
-		egg_test_success (test, "did not authenticate update-package, error '%s'", error);
-	else
-		egg_test_failed (test, "authenticated update-package!");
-	g_free (error);
-
 	g_object_unref (security);
 
 	egg_test_end (test);
