@@ -30,9 +30,8 @@
 #include "egg-debug.h"
 #include "egg-string.h"
 
-#include "pk-common.h"
 #include "pk-transaction-id.h"
-#define PK_TRANSACTION_ID_COUNT_FILE		LOCALSTATEDIR "/run/PackageKit/job_count.dat"
+#define PK_TRANSACTION_ID_COUNT_FILE		LOCALSTATEDIR "/lib/PackageKit/job_count.dat"
 
 /**
  * pk_transaction_id_get_random_hex_string:
