@@ -37,15 +37,14 @@
 #include <glib/gi18n.h>
 #include <dbus/dbus-glib.h>
 #include <dbus/dbus-glib-lowlevel.h>
-
-#include <pk-common.h>
+#include <packagekit-glib/packagekit.h>
 
 #include "egg-debug.h"
 #include "egg-string.h"
 
 #include "pk-transaction-id.h"
 #include "pk-transaction-list.h"
-#include "pk-interface-transaction.h"
+#include "org.freedesktop.PackageKit.Transaction.h"
 
 static void     pk_transaction_list_class_init	(PkTransactionListClass *klass);
 static void     pk_transaction_list_init	(PkTransactionList      *tlist);
@@ -57,7 +56,7 @@ static void     pk_transaction_list_finalize	(GObject        *object);
 #define PK_TRANSACTION_LIST_KEEP_FINISHED_TIMEOUT	5
 
 /* how long the tid is valid before it's destroyed, in seconds */
-#define PK_TRANSACTION_LIST_CREATE_COMMIT_TIMEOUT	5
+#define PK_TRANSACTION_LIST_CREATE_COMMIT_TIMEOUT	30
 
 /* the interval between each CST, in seconds */
 #define PK_TRANSACTION_WEDGE_CHECK			10
@@ -537,8 +536,9 @@ pk_transaction_list_print (PkTransactionList *tlist)
 	for (i=0; i<length; i++) {
 		item = (PkTransactionItem *) g_ptr_array_index (tlist->priv->array, i);
 		role = pk_transaction_priv_get_role (item->transaction);
-		g_print ("%0i\t%s\trunning[%i] committed[%i] finished[%i]\n", i,
-			 pk_role_enum_to_text (role), item->running, item->committed, item->finished);
+		g_print ("%0i\t%s\t%s\trunning[%i] committed[%i] finished[%i]\n", i,
+			 pk_role_enum_to_text (role), item->tid, item->running,
+			 item->committed, item->finished);
 	}
 }
 
@@ -756,6 +756,7 @@ pk_transaction_list_test_finished_cb (PkTransaction *transaction, const gchar *e
 static void
 pk_transaction_list_test_delay_cb (EggTest *test)
 {
+	egg_debug ("quitting loop");
 	egg_test_loop_quit (test);
 }
 
@@ -998,7 +999,7 @@ pk_transaction_list_test (EggTest *test)
 
 	/* wait for Cleanup */
 	g_timeout_add_seconds (5, (GSourceFunc) pk_transaction_list_test_delay_cb, test);
-	egg_test_loop_wait (test, 6000);
+	egg_test_loop_wait (test, 10000);
 	egg_test_loop_check (test);
 
 	/************************************************************/
@@ -1052,7 +1053,7 @@ pk_transaction_list_test (EggTest *test)
 
 	/* wait for Cleanup */
 	g_timeout_add_seconds (5, (GSourceFunc) pk_transaction_list_test_delay_cb, test);
-	egg_test_loop_wait (test, 6000);
+	egg_test_loop_wait (test, 10000);
 	egg_test_loop_check (test);
 
 	/************************************************************/
@@ -1125,7 +1126,7 @@ pk_transaction_list_test (EggTest *test)
 	g_strfreev (array);
 
 	/* wait for first action */
-	egg_test_loop_wait (test, 6000);
+	egg_test_loop_wait (test, 10000);
 	egg_test_loop_check (test);
 
 	/************************************************************/
@@ -1171,7 +1172,7 @@ pk_transaction_list_test (EggTest *test)
 				 item3->running, item3->committed, item3->finished);
 
 	/* wait for second action */
-	egg_test_loop_wait (test, 6000);
+	egg_test_loop_wait (test, 10000);
 	egg_test_loop_check (test);
 
 	/************************************************************/
@@ -1217,7 +1218,7 @@ pk_transaction_list_test (EggTest *test)
 				 item3->running, item3->committed, item3->finished);
 
 	/* wait for third action */
-	egg_test_loop_wait (test, 6000);
+	egg_test_loop_wait (test, 10000);
 	egg_test_loop_check (test);
 
 	/************************************************************/
@@ -1264,7 +1265,7 @@ pk_transaction_list_test (EggTest *test)
 
 	/* wait for Cleanup */
 	g_timeout_add_seconds (5, (GSourceFunc) pk_transaction_list_test_delay_cb, test);
-	egg_test_loop_wait (test, 6000);
+	egg_test_loop_wait (test, 10000);
 	egg_test_loop_check (test);
 
 	/************************************************************/
