@@ -24,9 +24,7 @@
 
 #include <glib-object.h>
 #include <dbus/dbus-glib.h>
-
-#include <pk-enum.h>
-#include <pk-package-list.h>
+#include <packagekit-glib/packagekit.h>
 
 G_BEGIN_DECLS
 
@@ -104,6 +102,8 @@ void		 pk_transaction_download_packages	(PkTransaction  *transaction,
 gboolean	 pk_transaction_get_allow_cancel	(PkTransaction	*transaction,
 							 gboolean	*allow_cancel,
 							 GError		**error);
+void		 pk_transaction_get_categories		(PkTransaction	*transaction,
+							 DBusGMethodInvocation *context);
 void		 pk_transaction_get_depends		(PkTransaction	*transaction,
 							 const gchar	*filter,
 							 gchar		**package_ids,
@@ -211,9 +211,6 @@ void		 pk_transaction_search_name		(PkTransaction	*transaction,
 gboolean	 pk_transaction_set_locale		(PkTransaction	*transaction,
 							 const gchar	*code,
 							 GError		**error);
-gboolean	 pk_transaction_service_pack		(PkTransaction	*transaction,
-							 const gchar	*location,
-							 gboolean	 enabled);
 void		 pk_transaction_update_packages		(PkTransaction	*transaction,
 							 gchar		**package_ids,
 							 DBusGMethodInvocation *context);
